/// AUTOGENERATED ON 2022-04-20 12:12:49.455452

import 'dart:convert';
import 'dart:typed_data';
import 'package:http/http.dart' as http;
import 'chunked_request.dart';

class PP {
  static String host = 'localhost';
  static int port = 50001;

  static config(String host, int port) {
    PP.host = host;
    PP.port = port;
  }

  /// [call] will use the response `content-type` to automatically
  /// determine if the response should be decoded from json or
  /// returned as [Uint8List] directly.
  static Future call(String verb, String path, {Map<String, dynamic>? params, Object? data}) async {
    var uri = Uri.http('$host:$port', path, params);
    var headers = {'content-type': 'application/json'};
    late http.Response r;
    switch (verb.toLowerCase()) {
      case 'get':
        r = await http.get(uri, headers: headers);
        break;
      case 'put':
        r = await http.put(uri, headers: headers, body: data);
        break;
      case 'delete':
        r = await http.delete(uri, headers: headers, body: data);
        break;
      case 'post':
        r = await http.post(uri, headers: headers, body: data);
        break;
      case 'patch':
        r = await http.patch(uri, headers: headers, body: data);
        break;
    }
    if (r.statusCode > 199 && r.statusCode < 300) {
      if (r.headers['content-type'] == 'application/json') {
        return json.decode(r.body);
      } else {
        return r.bodyBytes;
      }
    } else {
      throw http.ClientException(r.body);
    }
  }

  /// `annoucementActiveTimelineOperation` -> `/v1/announcement/active/timeline/{operation}`
  ///
  /// Performs the requested timeline operation for the active announcment presentation.
  ///
  ///
  /// ## PARAMETERS
  ///
  /// [operation] : The operation to perform on the timeline
  ///
  /// - Should be one of: `play`, `pause`, `rewind`
  ///
  ///
  /// ## RESPONSE 204:
  ///
  /// The request was processed successfully. There is no response body.
  ///
  /// content-type: `NONE`
  ///
  static Future<Uint8List> annoucementActiveTimelineOperation(String operation) async {
    String url = '/v1/announcement/active/timeline/$operation';

    return await call('get', url);
  }

  /// `announcementActiveTimelineStatus` -> `/v1/announcement/active/timeline`
  ///
  /// Requests the current state of the active announcement timeline.
  ///
  ///
  /// ## RESPONSE 200:
  ///
  /// The request was processed successfully.
  ///
  /// content-type: `application/json`
  ///
  /// schema:
  /// ```json
  /// {
  ///   "type": "object",
  ///   "required": []
  /// }
  /// ```
  static Future<Map<String, dynamic>> announcementActiveTimelineStatus() async {
    String url = '/v1/announcement/active/timeline';

    return await call('get', url);
  }

  /// Streaming version of [announcementActiveTimelineStatus]
  static Future<Stream?> announcementActiveTimelineStatusStream() async {
    String url = '/v1/announcement/active/timeline';

    var uri = Uri.http('$host:$port', url, {'chunked': 'true'});
    return ChunkedJsonClient.request(uri);
  }

  /// `audioPlaylistsGet` -> `/v1/audio/playlists`
  ///
  /// Requests a list with all the configured audio playlists.
  ///
  ///
  /// ## RESPONSE 200:
  ///
  /// The request was processed successfully.
  ///
  /// content-type: `application/json`
  ///
  /// schema:
  /// ```json
  /// {
  ///   "type": "array",
  ///   "required": []
  /// }
  /// ```
  static Future<Map<String, dynamic>> audioPlaylistsGet() async {
    String url = '/v1/audio/playlists';

    return await call('get', url);
  }

  /// `audioPlaylistGet` -> `/v1/audio/playlist/{playlist_id}`
  ///
  /// Requests a list of all the audio items in the specified audio playlist.
  ///
  ///
  /// ## PARAMETERS
  ///
  /// [playlistId] : The ID of the playlist, either UUID, name, or index, in order of interpretation and search priority. A path can also be specified to identify playlists within folders. UUID and name matches are searched through the entire playlist tree. Because UUIDs are unique a path is not necessary. A name path is not necessary unless there are multiple playlists with the same name in different folders. A partial path of names can be used as well. Indices only index into the immediate children at each level of the tree so an index path is requred to access playlists within folders if only using indices. A mix of UUIDs, names, and indices can be used for the path if desired.
  ///
  /// - Example (by_uuid): `3C39C433-5C18-4F51-B357-55BB870227C4`
  /// - Example (by_name): `Playlist Name`
  /// - Example (by_name_with_path): `Folder1/Folder2/Playlist Name`
  /// - Example (by_index): `3`
  /// - Example (by_index_path): `2/0/1`
  /// - Example (by_mixed_path): `3C39C433-5C18-4F51-B357-55BB870227C4/Folder Name/0`
  ///
  /// [start] : The starting index in the list. If the index is out of range, the returned items array will be empty.
  ///
  /// - Example (start): `100`
  ///
  /// ## RESPONSE 200:
  ///
  /// The request was processed successfully.
  ///
  /// content-type: `application/json`
  ///
  /// schema:
  /// ```json
  /// {
  ///   "type": "array",
  ///   "required": []
  /// }
  /// ```
  static Future<Map<String, dynamic>> audioPlaylistGet(String playlistId, {int? start}) async {
    String url = '/v1/audio/playlist/$playlistId';
    Map<String, dynamic> query = {'start': start.toString()};

    return await call('get', url, params: query);
  }

  /// `audioPlaylistUpdateGet` -> `/v1/audio/playlist/{playlist_id}/updates`
  ///
  /// Requests a chunked data update every time the specified audio playlist changes.
  ///
  ///
  /// ## PARAMETERS
  ///
  /// [playlistId] : The ID of the playlist, either UUID, name, or index, in order of interpretation and search priority. A path can also be specified to identify playlists within folders. UUID and name matches are searched through the entire playlist tree. Because UUIDs are unique a path is not necessary. A name path is not necessary unless there are multiple playlists with the same name in different folders. A partial path of names can be used as well. Indices only index into the immediate children at each level of the tree so an index path is requred to access playlists within folders if only using indices. A mix of UUIDs, names, and indices can be used for the path if desired.
  ///
  /// - Example (by_uuid): `3C39C433-5C18-4F51-B357-55BB870227C4`
  /// - Example (by_name): `Playlist Name`
  /// - Example (by_name_with_path): `Folder1/Folder2/Playlist Name`
  /// - Example (by_index): `3`
  /// - Example (by_index_path): `2/0/1`
  /// - Example (by_mixed_path): `3C39C433-5C18-4F51-B357-55BB870227C4/Folder Name/0`
  ///
  /// ## RESPONSE 200:
  ///
  /// The request was processed successfully.
  ///
  /// content-type: `application/json`
  ///
  /// schema:
  /// ```json
  /// {
  ///   "type": "string",
  ///   "required": [],
  ///   "enum": [
  ///     "change"
  ///   ]
  /// }
  /// ```
  static Future<Map<String, dynamic>> audioPlaylistUpdateGet(String playlistId) async {
    String url = '/v1/audio/playlist/$playlistId/updates';

    return await call('get', url);
  }

  /// Streaming version of [audioPlaylistUpdateGet]
  static Future<Stream?> audioPlaylistUpdateGetStream(String playlistId) async {
    String url = '/v1/audio/playlist/$playlistId/updates';

    var uri = Uri.http('$host:$port', url, {'chunked': 'true'});
    return ChunkedJsonClient.request(uri);
  }

  /// `captureStatusGet` -> `/v1/capture/status`
  ///
  /// Requests the current capture status and capture time.
  ///
  ///
  /// ## RESPONSE 200:
  ///
  /// The request was processed successfully.
  ///
  /// content-type: `application/json`
  ///
  /// schema:
  /// ```json
  /// {
  ///   "type": "object",
  ///   "required": [
  ///     "status",
  ///     "status_description"
  ///   ]
  /// }
  /// ```
  static Future<Map<String, dynamic>> captureStatusGet() async {
    String url = '/v1/capture/status';

    return await call('get', url);
  }

  /// Streaming version of [captureStatusGet]
  static Future<Stream?> captureStatusGetStream() async {
    String url = '/v1/capture/status';

    var uri = Uri.http('$host:$port', url, {'chunked': 'true'});
    return ChunkedJsonClient.request(uri);
  }

  /// `captureOperation` -> `/v1/capture/{operation}`
  ///
  /// Performs the requested capture operation (start, stop).
  ///
  ///
  /// ## PARAMETERS
  ///
  /// [operation] : The capture operation to perform
  ///
  /// - Should be one of: `start`, `stop`
  ///
  ///
  /// ## RESPONSE 204:
  ///
  /// The request was processed successfully. There is no response body.
  ///
  /// content-type: `NONE`
  ///
  static Future<Uint8List> captureOperation(String operation) async {
    String url = '/v1/capture/$operation';

    return await call('get', url);
  }

  /// `captureSettingsGet` -> `/v1/capture/settings`
  ///
  /// Requests the current capture settings.
  ///
  ///
  /// ## RESPONSE 200:
  ///
  /// The request was processed successfully.
  ///
  /// content-type: `application/json`
  ///
  /// schema:
  /// ```json
  /// {
  ///   "type": "object",
  ///   "required": [
  ///     "source",
  ///     "audio_routing"
  ///   ]
  /// }
  /// ```
  static Future<Map<String, dynamic>> captureSettingsGet() async {
    String url = '/v1/capture/settings';

    return await call('get', url);
  }

  /// `captureModesGet` -> `/v1/capture/encodings/{type}`
  ///
  /// Requests a list of all available capture modes for the capture type (disk, rtmp, resi).
  ///
  ///
  /// ## PARAMETERS
  ///
  /// [type] : The required capture type.
  ///
  /// - Should be one of: `disk`, `rtmp`, `resi`
  ///
  ///
  /// ## RESPONSE 200:
  ///
  /// The request was completed successfully.
  ///
  /// content-type: `application/json`
  ///
  /// schema:
  /// ```json
  /// {
  ///   "type": "array",
  ///   "required": []
  /// }
  /// ```
  static Future<Map<String, dynamic>> captureModesGet(String type) async {
    String url = '/v1/capture/encodings/$type';

    return await call('get', url);
  }

  /// `clearLayer` -> `/v1/clear/layer/{layer}`
  ///
  /// Clears the specified layer (audio, props, messages, announcements, slide, media, video_input).
  ///
  ///
  /// ## PARAMETERS
  ///
  /// [layer] : The name of layer that is to be cleared.
  ///
  /// - Should be one of: `audio`, `props`, `messages`, `announcements`, `slide`, `media`, `video_input`
  ///
  ///
  /// ## RESPONSE 204:
  ///
  /// The request was processed successfully. There is no response body.
  ///
  /// content-type: `NONE`
  ///
  static Future<Uint8List> clearLayer(String layer) async {
    String url = '/v1/clear/layer/$layer';

    return await call('get', url);
  }

  /// `clearGroupGet` -> `/v1/clear/group/{id}`
  ///
  /// Requests the details of the specified clear group.
  ///
  ///
  /// ## PARAMETERS
  /// [id] (required) :
  /// The ID of the required clear group, either name, index or UUID.
  ///
  /// - Example (by_name): `Clear Group`
  /// - Example (by_index): `3`
  /// - Example (by_uuid): `3C39C433-5C18-4F51-B357-55BB870227C4`
  ///
  /// ## RESPONSE 200:
  ///
  /// The request was processed successfully.
  ///
  /// content-type: `application/json`
  ///
  /// schema:
  /// ```json
  /// {
  ///   "type": "object",
  ///   "required": [
  ///     "id",
  ///     "layers",
  ///     "icon",
  ///     "tint",
  ///     "stop_timeline_announcements",
  ///     "stop_timeline_presentation",
  ///     "clear_next_presentation"
  ///   ]
  /// }
  /// ```
  static Future<Map<String, dynamic>> clearGroupGet(String id) async {
    String url = '/v1/clear/group/$id';

    return await call('get', url);
  }

  /// `clearGroupSet` -> `/v1/clear/group/{id}`
  ///
  /// Sets the details of the specified clear group.
  ///
  ///
  /// ## PARAMETERS
  /// [id] (required) :
  /// The ID of the required clear group, either name, index or UUID.
  ///
  /// - Example (by_name): `Clear Group`
  /// - Example (by_index): `3`
  /// - Example (by_uuid): `3C39C433-5C18-4F51-B357-55BB870227C4`
  ///
  /// [postBody] (required) : This is the data that must be sent with this request.
  ///
  /// ## RESPONSE 200:
  ///
  /// The request was processed successfully.
  ///
  /// content-type: `application/json`
  ///
  /// schema:
  /// ```json
  /// {
  ///   "type": "object",
  ///   "required": [
  ///     "id",
  ///     "layers",
  ///     "icon",
  ///     "tint",
  ///     "stop_timeline_announcements",
  ///     "stop_timeline_presentation",
  ///     "clear_next_presentation"
  ///   ]
  /// }
  /// ```
  ///
  /// ## RESPONSE 400:
  ///
  /// The request was not valid.
  ///
  /// content-type: ``
  ///
  static Future<Map<String, dynamic>> clearGroupSet(String id, Map postBody) async {
    String url = '/v1/clear/group/$id';

    return await call('put', url);
  }

  /// `clearGroupDelete` -> `/v1/clear/group/{id}`
  ///
  /// Deletes the specified clear group.
  ///
  ///
  /// ## PARAMETERS
  /// [id] (required) :
  /// The ID of the required clear group, either name, index or UUID.
  ///
  /// - Example (by_name): `Clear Group`
  /// - Example (by_index): `3`
  /// - Example (by_uuid): `3C39C433-5C18-4F51-B357-55BB870227C4`
  ///
  /// ## RESPONSE 204:
  ///
  /// The request was processed successfully. There is no response body.
  ///
  /// content-type: `NONE`
  ///
  static Future<Uint8List> clearGroupDelete(String id) async {
    String url = '/v1/clear/group/$id';

    return await call('delete', url);
  }

  /// `clearGroupIconGet` -> `/v1/clear/group/{id}/icon`
  ///
  /// Requests the image data for the icon of the specified clear group.
  ///
  ///
  /// ## PARAMETERS
  /// [id] (required) :
  /// The ID of the required clear group, either name, index or UUID.
  ///
  /// - Example (by_name): `Clear Group`
  /// - Example (by_index): `3`
  /// - Example (by_uuid): `3C39C433-5C18-4F51-B357-55BB870227C4`
  ///
  /// ## RESPONSE 200:
  ///
  /// The request was processed successfully.
  ///
  /// content-type: `image/jpeg`
  ///
  /// schema:
  /// ```json
  /// {
  ///   "type": "string",
  ///   "required": [],
  ///   "format": "binary",
  ///   "example": "image data here"
  /// }
  /// ```
  static Future<Uint8List> clearGroupIconGet(String id) async {
    String url = '/v1/clear/group/$id/icon';

    return await call('get', url);
  }

  /// `clearGroupIconSet` -> `/v1/clear/group/{id}/icon`
  ///
  /// Sets the custom icon of the specified clear group.
  ///
  ///
  /// ## PARAMETERS
  /// [id] (required) :
  /// The ID of the required clear group, either name, index or UUID.
  ///
  /// - Example (by_name): `Clear Group`
  /// - Example (by_index): `3`
  /// - Example (by_uuid): `3C39C433-5C18-4F51-B357-55BB870227C4`
  ///
  /// [postBody] (required) : This is the data that must be sent with this request.
  ///
  /// ## RESPONSE 204:
  ///
  /// The request was processed successfully. There is no response body.
  ///
  /// content-type: `NONE`
  ///
  static Future<Uint8List> clearGroupIconSet(String id, String postBody) async {
    String url = '/v1/clear/group/$id/icon';

    return await call('put', url);
  }

  /// `clearGroupTrigger` -> `/v1/clear/group/{id}/trigger`
  ///
  /// Triggers the specified clear group.
  ///
  ///
  /// ## PARAMETERS
  ///
  /// [id] : The ID of the required clear group, either name, index or UUID.
  ///
  /// - Example (by_name): `Clear Group`
  /// - Example (by_index): `3`
  /// - Example (by_uuid): `3C39C433-5C18-4F51-B357-55BB870227C4`
  ///
  /// ## RESPONSE 204:
  ///
  /// The request was processed successfully. There is no response body.
  ///
  /// content-type: `NONE`
  ///
  static Future<Uint8List> clearGroupTrigger(String id) async {
    String url = '/v1/clear/group/$id/trigger';

    return await call('get', url);
  }

  /// `clearGroupsGet` -> `/v1/clear/groups`
  ///
  /// Requests a list of all the configured clear groups.
  ///
  ///
  /// ## RESPONSE 200:
  ///
  /// The request was processed successfully.
  ///
  /// content-type: `application/json`
  ///
  /// schema:
  /// ```json
  /// {
  ///   "type": "array",
  ///   "required": []
  /// }
  /// ```
  static Future<Map<String, dynamic>> clearGroupsGet() async {
    String url = '/v1/clear/groups';

    return await call('get', url);
  }

  /// `clearGroupCreate` -> `/v1/clear/groups`
  ///
  /// Create a clear group with the details specified.
  ///
  ///
  /// ## PARAMETERS
  ///
  /// [postBody] (required) : This is the data that must be sent with this request.
  ///
  /// ## RESPONSE 200:
  ///
  /// The request was processed successfully.
  ///
  /// content-type: `application/json`
  ///
  /// schema:
  /// ```json
  /// {
  ///   "type": "object",
  ///   "required": [
  ///     "id",
  ///     "layers",
  ///     "icon",
  ///     "tint",
  ///     "stop_timeline_announcements",
  ///     "stop_timeline_presentation",
  ///     "clear_next_presentation"
  ///   ]
  /// }
  /// ```
  ///
  /// ## RESPONSE 400:
  ///
  /// The request was not valid.
  ///
  /// content-type: ``
  ///
  static Future<Map<String, dynamic>> clearGroupCreate(Map postBody) async {
    String url = '/v1/clear/groups';

    return await call('post', url);
  }

  /// `globalGroupsGet` -> `/v1/groups`
  ///
  /// Requests a list of all the configured global groups.
  ///
  ///
  /// ## RESPONSE 200:
  ///
  /// The request was processed successfully.
  ///
  /// content-type: `application/json`
  ///
  /// schema:
  /// ```json
  /// {
  ///   "type": "array",
  ///   "required": []
  /// }
  /// ```
  static Future<Map<String, dynamic>> globalGroupsGet() async {
    String url = '/v1/groups';

    return await call('get', url);
  }

  /// `globalGroupTrigger` -> `/v1/group/{id}`
  ///
  /// Triggers the specified global group.
  ///
  ///
  /// ## PARAMETERS
  ///
  /// [id] : The ID of the required global group, either name, index or UUID.
  ///
  /// - Example (by_name): `Verse 1`
  /// - Example (by_index): `0`
  /// - Example (by_uuid): `3C39C433-5C18-4F51-B357-55BB870227C4`
  ///
  /// ## RESPONSE 204:
  ///
  /// The request was processed successfully. There is no response body.
  ///
  /// content-type: `NONE`
  ///
  static Future<Uint8List> globalGroupTrigger(String id) async {
    String url = '/v1/group/$id';

    return await call('get', url);
  }

  /// `libraryListGet` -> `/v1/libraries`
  ///
  /// Requests a list of all the configured libraries.
  ///
  ///
  /// ## RESPONSE 200:
  ///
  /// The request was processed successfully.
  ///
  /// content-type: `application/json`
  ///
  /// schema:
  /// ```json
  /// {
  ///   "type": "array",
  ///   "required": []
  /// }
  /// ```
  static Future<Map<String, dynamic>> libraryListGet() async {
    String url = '/v1/libraries';

    return await call('get', url);
  }

  /// `libraryGet` -> `/v1/library/{library_id}`
  ///
  /// Requests an array of all items in the specified library.
  ///
  ///
  /// ## PARAMETERS
  ///
  /// [libraryId] : The ID of the library, either UUID, name, or index, in order of interpretation and search priority.
  ///
  /// - Example (by_uuid): `3C39C433-5C18-4F51-B357-55BB870227C4`
  /// - Example (by_name): `Library Name`
  /// - Example (by_index): `3`
  ///
  /// ## RESPONSE 200:
  ///
  /// The request was processed successfully.
  ///
  /// content-type: `application/json`
  ///
  /// schema:
  /// ```json
  /// {
  ///   "type": "object",
  ///   "required": [
  ///     "updateType",
  ///     "items"
  ///   ]
  /// }
  /// ```
  static Future<Map<String, dynamic>> libraryGet(String libraryId) async {
    String url = '/v1/library/$libraryId';

    return await call('get', url);
  }

  /// Streaming version of [libraryGet]
  static Future<Stream?> libraryGetStream(String libraryId) async {
    String url = '/v1/library/$libraryId';

    var uri = Uri.http('$host:$port', url, {'chunked': 'true'});
    return ChunkedJsonClient.request(uri);
  }

  /// `lookGetAll` -> `/v1/looks`
  ///
  /// Requests a list of all configured audience looks, except the live look.
  ///
  ///
  /// ## RESPONSE 200:
  ///
  /// The request was processed successfully.
  ///
  /// content-type: `application/json`
  ///
  /// schema:
  /// ```json
  /// {
  ///   "type": "array",
  ///   "required": []
  /// }
  /// ```
  static Future<Map<String, dynamic>> lookGetAll() async {
    String url = '/v1/looks';

    return await call('get', url);
  }

  /// `lookCreate` -> `/v1/looks`
  ///
  /// Creates a new audience look with the specified details.
  ///
  ///
  /// ## PARAMETERS
  ///
  /// [postBody] (required) : This is the data that must be sent with this request.
  ///
  /// Example:
  /// ```json
  /// {
  ///   "id": {
  ///     "uuid": "42C3FC3-C4B2-44F7-A55D-4CC913BB8A5C",
  ///     "name": "Look",
  ///     "index": 0
  ///   },
  ///   "screens": [
  ///     {
  ///       "video_input": true,
  ///       "media": true,
  ///       "slide": true,
  ///       "announcements": true,
  ///       "props": true,
  ///       "messages": true,
  ///       "presentation": "42C3FC3-C4B2-44F7-A55D-4CC913BB8A5D",
  ///       "mask": "42C3FC3-C4B2-44F7-A55D-4CC913BB8A5E"
  ///     },
  ///     {
  ///       "video_input": true,
  ///       "media": true,
  ///       "slide": true,
  ///       "announcements": true,
  ///       "props": true,
  ///       "messages": true,
  ///       "presentation": "42C3FC3-C4B2-44F7-A55D-4CC913BB8A5D",
  ///       "mask": null
  ///     },
  ///     {
  ///       "video_input": false,
  ///       "media": false,
  ///       "slide": false,
  ///       "announcements": true,
  ///       "props": false,
  ///       "messages": false,
  ///       "presentation": null,
  ///       "mask": null
  ///     }
  ///   ]
  /// }
  /// ```
  ///
  /// ## RESPONSE 200:
  ///
  /// The request was processed successfully.
  ///
  /// content-type: `application/json`
  ///
  /// schema:
  /// ```json
  /// {
  ///   "type": "object",
  ///   "required": [
  ///     "uuid",
  ///     "index",
  ///     "name",
  ///     "screens"
  ///   ],
  ///   "example": {
  ///     "id": {
  ///       "uuid": "42C3FC3-C4B2-44F7-A55D-4CC913BB8A5C",
  ///       "name": "Look",
  ///       "index": 0
  ///     },
  ///     "screens": [
  ///       {
  ///         "video_input": true,
  ///         "media": true,
  ///         "slide": true,
  ///         "announcements": true,
  ///         "props": true,
  ///         "messages": true,
  ///         "presentation": "42C3FC3-C4B2-44F7-A55D-4CC913BB8A5D",
  ///         "mask": "42C3FC3-C4B2-44F7-A55D-4CC913BB8A5E"
  ///       },
  ///       {
  ///         "video_input": true,
  ///         "media": true,
  ///         "slide": true,
  ///         "announcements": true,
  ///         "props": true,
  ///         "messages": true,
  ///         "presentation": "42C3FC3-C4B2-44F7-A55D-4CC913BB8A5D",
  ///         "mask": null
  ///       },
  ///       {
  ///         "video_input": false,
  ///         "media": false,
  ///         "slide": false,
  ///         "announcements": true,
  ///         "props": false,
  ///         "messages": false,
  ///         "presentation": null,
  ///         "mask": null
  ///       }
  ///     ]
  ///   }
  /// }
  /// ```
  ///
  /// ## RESPONSE 400:
  ///
  /// The request was not valid.
  ///
  /// content-type: ``
  ///
  static Future<Map<String, dynamic>> lookCreate(Map postBody) async {
    String url = '/v1/looks';

    return await call('post', url);
  }

  /// `lookGetCurrent` -> `/v1/look/current`
  ///
  /// Requests the details of the currently live audience look.
  ///
  ///
  /// ## RESPONSE 200:
  ///
  /// The request was processed successfully.
  ///
  /// content-type: `application/json`
  ///
  /// schema:
  /// ```json
  /// {
  ///   "type": "object",
  ///   "required": [
  ///     "uuid",
  ///     "index",
  ///     "name",
  ///     "screens"
  ///   ],
  ///   "example": {
  ///     "id": {
  ///       "uuid": "42C3FC3-C4B2-44F7-A55D-4CC913BB8A5C",
  ///       "name": "Look",
  ///       "index": 0
  ///     },
  ///     "screens": [
  ///       {
  ///         "video_input": true,
  ///         "media": true,
  ///         "slide": true,
  ///         "announcements": true,
  ///         "props": true,
  ///         "messages": true,
  ///         "presentation": "42C3FC3-C4B2-44F7-A55D-4CC913BB8A5D",
  ///         "mask": "42C3FC3-C4B2-44F7-A55D-4CC913BB8A5E"
  ///       },
  ///       {
  ///         "video_input": true,
  ///         "media": true,
  ///         "slide": true,
  ///         "announcements": true,
  ///         "props": true,
  ///         "messages": true,
  ///         "presentation": "42C3FC3-C4B2-44F7-A55D-4CC913BB8A5D",
  ///         "mask": null
  ///       },
  ///       {
  ///         "video_input": false,
  ///         "media": false,
  ///         "slide": false,
  ///         "announcements": true,
  ///         "props": false,
  ///         "messages": false,
  ///         "presentation": null,
  ///         "mask": null
  ///       }
  ///     ]
  ///   }
  /// }
  /// ```
  static Future<Map<String, dynamic>> lookGetCurrent() async {
    String url = '/v1/look/current';

    return await call('get', url);
  }

  /// Streaming version of [lookGetCurrent]
  static Future<Stream?> lookGetCurrentStream() async {
    String url = '/v1/look/current';

    var uri = Uri.http('$host:$port', url, {'chunked': 'true'});
    return ChunkedJsonClient.request(uri);
  }

  /// `lookSetCurrent` -> `/v1/look/current`
  ///
  /// Sets the details of the currently live audience look.
  ///
  ///
  /// ## PARAMETERS
  ///
  /// [postBody] (optional) : This is the data that can be sent with this request.
  ///
  /// Example:
  /// ```json
  /// {
  ///   "id": {
  ///     "uuid": "42C3FC3-C4B2-44F7-A55D-4CC913BB8A5C",
  ///     "name": "Look",
  ///     "index": 0
  ///   },
  ///   "screens": [
  ///     {
  ///       "video_input": true,
  ///       "media": true,
  ///       "slide": true,
  ///       "announcements": true,
  ///       "props": true,
  ///       "messages": true,
  ///       "presentation": "42C3FC3-C4B2-44F7-A55D-4CC913BB8A5D",
  ///       "mask": "42C3FC3-C4B2-44F7-A55D-4CC913BB8A5E"
  ///     },
  ///     {
  ///       "video_input": true,
  ///       "media": true,
  ///       "slide": true,
  ///       "announcements": true,
  ///       "props": true,
  ///       "messages": true,
  ///       "presentation": "42C3FC3-C4B2-44F7-A55D-4CC913BB8A5D",
  ///       "mask": null
  ///     },
  ///     {
  ///       "video_input": false,
  ///       "media": false,
  ///       "slide": false,
  ///       "announcements": true,
  ///       "props": false,
  ///       "messages": false,
  ///       "presentation": null,
  ///       "mask": null
  ///     }
  ///   ]
  /// }
  /// ```
  ///
  /// ## RESPONSE 204:
  ///
  /// The request was processed successfully. There is no response body.
  ///
  /// content-type: `NONE`
  ///
  /// ## RESPONSE 400:
  ///
  /// The request was not valid.
  ///
  /// content-type: ``
  ///
  static Future<Uint8List> lookSetCurrent(Map postBody) async {
    String url = '/v1/look/current';

    return await call('put', url);
  }

  /// `lookGet` -> `/v1/look/{id}`
  ///
  /// Requests the details of the specified audience look.
  ///
  ///
  /// ## PARAMETERS
  /// [id] (required) :
  /// The ID of the audience look, either UUID, name, or index.
  ///
  /// - Example (by_uuid): `3C39C433-5C18-4F51-B357-55BB870227C4`
  /// - Example (by_name): `Look`
  /// - Example (by_index): `3`
  ///
  /// ## RESPONSE 200:
  ///
  /// The request was processed successfully.
  ///
  /// content-type: `application/json`
  ///
  /// schema:
  /// ```json
  /// {
  ///   "type": "object",
  ///   "required": [
  ///     "uuid",
  ///     "index",
  ///     "name",
  ///     "screens"
  ///   ],
  ///   "example": {
  ///     "id": {
  ///       "uuid": "42C3FC3-C4B2-44F7-A55D-4CC913BB8A5C",
  ///       "name": "Look",
  ///       "index": 0
  ///     },
  ///     "screens": [
  ///       {
  ///         "video_input": true,
  ///         "media": true,
  ///         "slide": true,
  ///         "announcements": true,
  ///         "props": true,
  ///         "messages": true,
  ///         "presentation": "42C3FC3-C4B2-44F7-A55D-4CC913BB8A5D",
  ///         "mask": "42C3FC3-C4B2-44F7-A55D-4CC913BB8A5E"
  ///       },
  ///       {
  ///         "video_input": true,
  ///         "media": true,
  ///         "slide": true,
  ///         "announcements": true,
  ///         "props": true,
  ///         "messages": true,
  ///         "presentation": "42C3FC3-C4B2-44F7-A55D-4CC913BB8A5D",
  ///         "mask": null
  ///       },
  ///       {
  ///         "video_input": false,
  ///         "media": false,
  ///         "slide": false,
  ///         "announcements": true,
  ///         "props": false,
  ///         "messages": false,
  ///         "presentation": null,
  ///         "mask": null
  ///       }
  ///     ]
  ///   }
  /// }
  /// ```
  static Future<Map<String, dynamic>> lookGet(String id) async {
    String url = '/v1/look/$id';

    return await call('get', url);
  }

  /// `lookPut` -> `/v1/look/{id}`
  ///
  /// Sets the details of the specified audience look.
  ///
  ///
  /// ## PARAMETERS
  /// [id] (required) :
  /// The ID of the audience look, either UUID, name, or index.
  ///
  /// - Example (by_uuid): `3C39C433-5C18-4F51-B357-55BB870227C4`
  /// - Example (by_name): `Look`
  /// - Example (by_index): `3`
  ///
  /// [postBody] (required) : This is the data that must be sent with this request.
  ///
  /// Example:
  /// ```json
  /// {
  ///   "id": {
  ///     "uuid": "42C3FC3-C4B2-44F7-A55D-4CC913BB8A5C",
  ///     "name": "Look",
  ///     "index": 0
  ///   },
  ///   "screens": [
  ///     {
  ///       "video_input": true,
  ///       "media": true,
  ///       "slide": true,
  ///       "announcements": true,
  ///       "props": true,
  ///       "messages": true,
  ///       "presentation": "42C3FC3-C4B2-44F7-A55D-4CC913BB8A5D",
  ///       "mask": "42C3FC3-C4B2-44F7-A55D-4CC913BB8A5E"
  ///     },
  ///     {
  ///       "video_input": true,
  ///       "media": true,
  ///       "slide": true,
  ///       "announcements": true,
  ///       "props": true,
  ///       "messages": true,
  ///       "presentation": "42C3FC3-C4B2-44F7-A55D-4CC913BB8A5D",
  ///       "mask": null
  ///     },
  ///     {
  ///       "video_input": false,
  ///       "media": false,
  ///       "slide": false,
  ///       "announcements": true,
  ///       "props": false,
  ///       "messages": false,
  ///       "presentation": null,
  ///       "mask": null
  ///     }
  ///   ]
  /// }
  /// ```
  ///
  /// ## RESPONSE 200:
  ///
  /// The request was processed successfully.
  ///
  /// content-type: `application/json`
  ///
  /// schema:
  /// ```json
  /// {
  ///   "type": "object",
  ///   "required": [
  ///     "uuid",
  ///     "index",
  ///     "name",
  ///     "screens"
  ///   ],
  ///   "example": {
  ///     "id": {
  ///       "uuid": "42C3FC3-C4B2-44F7-A55D-4CC913BB8A5C",
  ///       "name": "Look",
  ///       "index": 0
  ///     },
  ///     "screens": [
  ///       {
  ///         "video_input": true,
  ///         "media": true,
  ///         "slide": true,
  ///         "announcements": true,
  ///         "props": true,
  ///         "messages": true,
  ///         "presentation": "42C3FC3-C4B2-44F7-A55D-4CC913BB8A5D",
  ///         "mask": "42C3FC3-C4B2-44F7-A55D-4CC913BB8A5E"
  ///       },
  ///       {
  ///         "video_input": true,
  ///         "media": true,
  ///         "slide": true,
  ///         "announcements": true,
  ///         "props": true,
  ///         "messages": true,
  ///         "presentation": "42C3FC3-C4B2-44F7-A55D-4CC913BB8A5D",
  ///         "mask": null
  ///       },
  ///       {
  ///         "video_input": false,
  ///         "media": false,
  ///         "slide": false,
  ///         "announcements": true,
  ///         "props": false,
  ///         "messages": false,
  ///         "presentation": null,
  ///         "mask": null
  ///       }
  ///     ]
  ///   }
  /// }
  /// ```
  ///
  /// ## RESPONSE 400:
  ///
  /// The request was not valid.
  ///
  /// content-type: ``
  ///
  static Future<Map<String, dynamic>> lookPut(String id, Map postBody) async {
    String url = '/v1/look/$id';

    return await call('put', url);
  }

  /// `lookDelete` -> `/v1/look/{id}`
  ///
  /// Deletes the specified audience look from the saved looks.
  ///
  ///
  /// ## PARAMETERS
  /// [id] (required) :
  /// The ID of the audience look, either UUID, name, or index.
  ///
  /// - Example (by_uuid): `3C39C433-5C18-4F51-B357-55BB870227C4`
  /// - Example (by_name): `Look`
  /// - Example (by_index): `3`
  ///
  /// ## RESPONSE 204:
  ///
  /// The request was processed successfully. There is no response body.
  ///
  /// content-type: `NONE`
  ///
  static Future<Uint8List> lookDelete(String id) async {
    String url = '/v1/look/$id';

    return await call('delete', url);
  }

  /// `lookTrigger` -> `/v1/look/{id}/trigger`
  ///
  /// Triggers the specified audience look to make it the live/current look.
  ///
  ///
  /// ## PARAMETERS
  ///
  /// [id] : The ID of the audience look, either UUID, name, or index.
  ///
  /// - Example (by_uuid): `3C39C433-5C18-4F51-B357-55BB870227C4`
  /// - Example (by_name): `Look`
  /// - Example (by_index): `3`
  ///
  /// ## RESPONSE 204:
  ///
  /// The request was processed successfully. There is no response body.
  ///
  /// content-type: `NONE`
  ///
  static Future<Uint8List> lookTrigger(String id) async {
    String url = '/v1/look/$id/trigger';

    return await call('get', url);
  }

  /// `macroGetAll` -> `/v1/macros`
  ///
  /// Requests a list of all the configured macros.
  ///
  ///
  /// ## RESPONSE 200:
  ///
  /// The request was processed successfully.
  ///
  /// content-type: `application/json`
  ///
  /// schema:
  /// ```json
  /// {
  ///   "type": "array",
  ///   "required": []
  /// }
  /// ```
  static Future<Map<String, dynamic>> macroGetAll() async {
    String url = '/v1/macros';

    return await call('get', url);
  }

  /// `macroGet` -> `/v1/macro/{id}`
  ///
  /// Requests the details of the specified macro.
  ///
  ///
  /// ## PARAMETERS
  /// [id] (required) :
  /// The ID of the macro, either UUID, name, or index.
  ///
  /// - Example (by_uuid): `3C39C433-5C18-4F51-B357-55BB870227C4`
  /// - Example (by_name): `Macro`
  /// - Example (by_index): `3`
  ///
  /// ## RESPONSE 200:
  ///
  /// The request was processed successfully.
  ///
  /// content-type: `application/json`
  ///
  /// schema:
  /// ```json
  /// {
  ///   "type": "object",
  ///   "required": [
  ///     "id",
  ///     "color"
  ///   ]
  /// }
  /// ```
  static Future<Map<String, dynamic>> macroGet(String id) async {
    String url = '/v1/macro/$id';

    return await call('get', url);
  }

  /// `macroSet` -> `/v1/macro/{id}`
  ///
  /// Sets the details of the specified macro.
  ///
  ///
  /// ## PARAMETERS
  /// [id] (required) :
  /// The ID of the macro, either UUID, name, or index.
  ///
  /// - Example (by_uuid): `3C39C433-5C18-4F51-B357-55BB870227C4`
  /// - Example (by_name): `Macro`
  /// - Example (by_index): `3`
  ///
  /// [postBody] (required) : This is the data that must be sent with this request.
  ///
  /// ## RESPONSE 200:
  ///
  /// The request was processed successfully.
  ///
  /// content-type: `application/json`
  ///
  /// schema:
  /// ```json
  /// {
  ///   "type": "object",
  ///   "required": [
  ///     "id",
  ///     "color"
  ///   ]
  /// }
  /// ```
  ///
  /// ## RESPONSE 400:
  ///
  /// The request was not valid.
  ///
  /// content-type: ``
  ///
  static Future<Map<String, dynamic>> macroSet(String id, Map postBody) async {
    String url = '/v1/macro/$id';

    return await call('put', url);
  }

  /// `macroDelete` -> `/v1/macro/{id}`
  ///
  /// Deletes the specified macro.
  ///
  ///
  /// ## PARAMETERS
  /// [id] (required) :
  /// The ID of the macro, either UUID, name, or index.
  ///
  /// - Example (by_uuid): `3C39C433-5C18-4F51-B357-55BB870227C4`
  /// - Example (by_name): `Macro`
  /// - Example (by_index): `3`
  ///
  /// ## RESPONSE 204:
  ///
  /// The request was processed successfully. There is no response body.
  ///
  /// content-type: `NONE`
  ///
  static Future<Uint8List> macroDelete(String id) async {
    String url = '/v1/macro/$id';

    return await call('delete', url);
  }

  /// `macroTrigger` -> `/v1/macro/{id}/trigger`
  ///
  /// Triggers the specified macro.
  ///
  ///
  /// ## PARAMETERS
  ///
  /// [id] : The ID of the macro, either UUID, name, or index.
  ///
  /// - Example (by_uuid): `3C39C433-5C18-4F51-B357-55BB870227C4`
  /// - Example (by_name): `Macro`
  /// - Example (by_index): `3`
  ///
  /// ## RESPONSE 204:
  ///
  /// The request was processed successfully. There is no response body.
  ///
  /// content-type: `NONE`
  ///
  /// ## RESPONSE 400:
  ///
  /// The request was not valid.
  ///
  /// content-type: ``
  ///
  static Future<Uint8List> macroTrigger(String id) async {
    String url = '/v1/macro/$id/trigger';

    return await call('get', url);
  }

  /// `maskGetAll` -> `/v1/masks`
  ///
  /// Requests a list of all configured masks.
  ///
  ///
  /// ## RESPONSE 200:
  ///
  /// The request was processed successfully.
  ///
  /// content-type: `application/json`
  ///
  /// schema:
  /// ```json
  /// {
  ///   "type": "array",
  ///   "required": []
  /// }
  /// ```
  static Future<Map<String, dynamic>> maskGetAll() async {
    String url = '/v1/masks';

    return await call('get', url);
  }

  /// `maskGet` -> `/v1/mask/{id}`
  ///
  /// Requests the details of the specified mask.
  ///
  ///
  /// ## PARAMETERS
  ///
  /// [id] : The ID of the mask, either UUID, name, or index.
  ///
  /// - Example (by_uuid): `3C39C433-5C18-4F51-B357-55BB870227C4`
  /// - Example (by_name): `Mask`
  /// - Example (by_index): `3`
  ///
  /// ## RESPONSE 200:
  ///
  /// The request was processed successfully.
  ///
  /// content-type: `application/json`
  ///
  /// schema:
  /// ```json
  /// {
  ///   "type": "object",
  ///   "required": [
  ///     "id"
  ///   ]
  /// }
  /// ```
  static Future<Map<String, dynamic>> maskGet(String id) async {
    String url = '/v1/mask/$id';

    return await call('get', url);
  }

  /// `maskThumbnailGet` -> `/v1/mask/{id}/thumbnail`
  ///
  /// Requests a thumbnail image of the specified mask at the given quality value.
  ///
  ///
  /// ## PARAMETERS
  ///
  /// [id] : The ID of the mask, either UUID, name, or index.
  ///
  /// - Example (by_uuid): `3C39C433-5C18-4F51-B357-55BB870227C4`
  /// - Example (by_name): `Mask`
  /// - Example (by_index): `3`
  ///
  /// [quality] : The desired quality of the thumbnail. The value is the number of pixels in the _largest_ dimension of the image,
  /// i.e. if the image is landscape (wider than it is tall), it is the _width_ of the image. If the image is portrait
  /// (taller than it is wide), it is the _height_ of the image.
  ///
  /// Example: `400`
  ///
  /// ## RESPONSE 200:
  ///
  /// The request was processed successfully.
  ///
  /// content-type: `image/jpeg`
  ///
  /// schema:
  /// ```json
  /// {
  ///   "type": "string",
  ///   "required": [],
  ///   "format": "binary",
  ///   "example": "image data here"
  /// }
  /// ```
  static Future<Uint8List> maskThumbnailGet(String id, {int? quality}) async {
    String url = '/v1/mask/$id/thumbnail';
    Map<String, dynamic> query = {'quality': quality.toString()};

    return await call('get', url, params: query);
  }

  /// `mediaPlaylistsGet` -> `/v1/media/playlists`
  ///
  /// Requests a list of all the configured media playlists.
  ///
  ///
  /// ## RESPONSE 200:
  ///
  /// The request was processed successfully.
  ///
  /// content-type: `application/json`
  ///
  /// schema:
  /// ```json
  /// {
  ///   "type": "array",
  ///   "required": []
  /// }
  /// ```
  static Future<Map<String, dynamic>> mediaPlaylistsGet() async {
    String url = '/v1/media/playlists';

    return await call('get', url);
  }

  /// `mediaPlaylistGet` -> `/v1/media/playlist/{playlist_id}`
  ///
  /// Requests a list of all the media items in the specified media playlist.
  ///
  ///
  /// ## PARAMETERS
  ///
  /// [playlistId] : The ID of the playlist, either UUID, name, or index, in order of interpretation and search priority. A path can also be specified to identify playlists within folders. UUID and name matches are searched through the entire playlist tree. Because UUIDs are unique a path is not necessary. A name path is not necessary unless there are multiple playlists with the same name in different folders. A partial path of names can be used as well. Indices only index into the immediate children at each level of the tree so an index path is requred to access playlists within folders if only using indices. A mix of UUIDs, names, and indices can be used for the path if desired.
  ///
  /// - Example (by_uuid): `3C39C433-5C18-4F51-B357-55BB870227C4`
  /// - Example (by_name): `Playlist Name`
  /// - Example (by_name_with_path): `Folder1/Folder2/Playlist Name`
  /// - Example (by_index): `3`
  /// - Example (by_index_path): `2/0/1`
  /// - Example (by_mixed_path): `3C39C433-5C18-4F51-B357-55BB870227C4/Folder Name/0`
  ///
  /// [start] : The starting index in the list. If the index is out of range, the returned items array will be empty.
  ///
  /// - Example (start): `100`
  ///
  /// ## RESPONSE 200:
  ///
  /// The request was processed successfully.
  ///
  /// content-type: `application/json`
  ///
  /// schema:
  /// ```json
  /// {
  ///   "type": "array",
  ///   "required": []
  /// }
  /// ```
  static Future<Map<String, dynamic>> mediaPlaylistGet(String playlistId, {int? start}) async {
    String url = '/v1/media/playlist/$playlistId';
    Map<String, dynamic> query = {'start': start.toString()};

    return await call('get', url, params: query);
  }

  /// `mediaPlaylistUpdateGet` -> `/v1/media/playlist/{playlist_id}/updates`
  ///
  /// Requests a chunked data update every time the specified media playlist changes.
  ///
  ///
  /// ## PARAMETERS
  ///
  /// [playlistId] : The ID of the playlist, either UUID, name, or index, in order of interpretation and search priority. A path can also be specified to identify playlists within folders. UUID and name matches are searched through the entire playlist tree. Because UUIDs are unique a path is not necessary. A name path is not necessary unless there are multiple playlists with the same name in different folders. A partial path of names can be used as well. Indices only index into the immediate children at each level of the tree so an index path is requred to access playlists within folders if only using indices. A mix of UUIDs, names, and indices can be used for the path if desired.
  ///
  /// - Example (by_uuid): `3C39C433-5C18-4F51-B357-55BB870227C4`
  /// - Example (by_name): `Playlist Name`
  /// - Example (by_name_with_path): `Folder1/Folder2/Playlist Name`
  /// - Example (by_index): `3`
  /// - Example (by_index_path): `2/0/1`
  /// - Example (by_mixed_path): `3C39C433-5C18-4F51-B357-55BB870227C4/Folder Name/0`
  ///
  /// ## RESPONSE 200:
  ///
  /// The request was processed successfully.
  ///
  /// content-type: `application/json`
  ///
  /// schema:
  /// ```json
  /// {
  ///   "type": "string",
  ///   "required": [],
  ///   "enum": [
  ///     "change"
  ///   ]
  /// }
  /// ```
  static Future<Map<String, dynamic>> mediaPlaylistUpdateGet(String playlistId) async {
    String url = '/v1/media/playlist/$playlistId/updates';

    return await call('get', url);
  }

  /// Streaming version of [mediaPlaylistUpdateGet]
  static Future<Stream?> mediaPlaylistUpdateGetStream(String playlistId) async {
    String url = '/v1/media/playlist/$playlistId/updates';

    var uri = Uri.http('$host:$port', url, {'chunked': 'true'});
    return ChunkedJsonClient.request(uri);
  }

  /// `mediaThumbnailGet` -> `/v1/media/{uuid}/thumbnail`
  ///
  /// Requests a thumbnail image of the specified media item at the given quality value.
  ///
  ///
  /// ## PARAMETERS
  ///
  /// [uuid] : The UUID of the item to look up.
  ///
  /// - Example (uuid): `3C39C433-5C18-4F51-B357-55BB870227C4`
  ///
  /// [quality] : The desired quality of the thumbnail. The value is the number of pixels in the _largest_ dimension of the image,
  /// i.e. if the image is landscape (wider than it is tall), it is the _width_ of the image. If the image is portrait
  /// (taller than it is wide), it is the _height_ of the image.
  ///
  /// Example: `400`
  ///
  /// ## RESPONSE 200:
  ///
  /// The request was processed successfully.
  ///
  /// content-type: `image/jpeg`
  ///
  /// schema:
  /// ```json
  /// {
  ///   "type": "string",
  ///   "required": [],
  ///   "format": "binary",
  ///   "example": "image data here"
  /// }
  /// ```
  static Future<Uint8List> mediaThumbnailGet(String uuid, {int? quality}) async {
    String url = '/v1/media/$uuid/thumbnail';
    Map<String, dynamic> query = {'quality': quality.toString()};

    return await call('get', url, params: query);
  }

  /// `messageGetAll` -> `/v1/messages`
  ///
  /// Requests a list of all configured messages.
  ///
  ///
  /// ## RESPONSE 200:
  ///
  /// The request was processed successfully.
  ///
  /// content-type: `application/json`
  ///
  /// schema:
  /// ```json
  /// {
  ///   "type": "array",
  ///   "required": []
  /// }
  /// ```
  static Future<Map<String, dynamic>> messageGetAll() async {
    String url = '/v1/messages';

    return await call('get', url);
  }

  /// Streaming version of [messageGetAll]
  static Future<Stream?> messageGetAllStream() async {
    String url = '/v1/messages';

    var uri = Uri.http('$host:$port', url, {'chunked': 'true'});
    return ChunkedJsonClient.request(uri);
  }

  /// `messageCreate` -> `/v1/messages`
  ///
  /// Creates a new message with specified details.
  ///
  ///
  /// ## PARAMETERS
  ///
  /// [postBody] (required) : This is the data that must be sent with this request.
  ///
  /// Example:
  /// ```json
  /// {
  ///   "id": {
  ///     "name": "Test Message",
  ///     "uuid": "942C3FC3-C4B2-44F7-A55D-4CC913BB8A5D",
  ///     "index": 0
  ///   },
  ///   "message": "Text {text}, Clock {System Clock}, Countdown {Timer 1}, Countdown to time {Timer 2}, Elapsed {Timer 3}",
  ///   "tokens": [
  ///     {
  ///       "name": "text",
  ///       "text": {
  ///         "text": "142"
  ///       }
  ///     },
  ///     {
  ///       "name": "System Clock",
  ///       "clock": {
  ///         "format": {
  ///           "date": "short",
  ///           "time": "long",
  ///           "is_24_hours": true
  ///         }
  ///       }
  ///     },
  ///     {
  ///       "name": "Timer 1",
  ///       "timer": {
  ///         "configuration": {
  ///           "id": {
  ///             "name": "Timer 1",
  ///             "uuid": "43b4c5c6-145a-4b19-9968-7b78e6980e82",
  ///             "index": 0
  ///           },
  ///           "allows_overrun": true,
  ///           "countdown": {
  ///             "duration": 300
  ///           }
  ///         },
  ///         "format": {
  ///           "hour": "remove_long",
  ///           "minute": "remove_long",
  ///           "second": "short",
  ///           "millisecond": "none"
  ///         }
  ///       }
  ///     },
  ///     {
  ///       "name": "Timer 2",
  ///       "timer": {
  ///         "configuration": {
  ///           "id": {
  ///             "name": "Timer 2",
  ///             "uuid": "1355b458-5f99-4e6e-8ac7-8522061f6bdb",
  ///             "index": 0
  ///           },
  ///           "allows_overrun": true,
  ///           "count_down_to_time": {
  ///             "time_of_day": "09:30",
  ///             "period": "am"
  ///           }
  ///         },
  ///         "format": {
  ///           "hour": "remove_long",
  ///           "minute": "remove_long",
  ///           "second": "short",
  ///           "millisecond": "none"
  ///         }
  ///       }
  ///     },
  ///     {
  ///       "name": "Timer 3",
  ///       "timer": {
  ///         "configuration": {
  ///           "id": {
  ///             "name": "Timer 3",
  ///             "uuid": "8efe5ec8-daf4-4609-aea2-7c80efa7f6fa",
  ///             "index": 0
  ///           },
  ///           "allows_overrun": true,
  ///           "elapsed": {
  ///             "start_time": 0
  ///           }
  ///         },
  ///         "format": {
  ///           "hour": "remove_long",
  ///           "minute": "remove_long",
  ///           "second": "short",
  ///           "millisecond": "none"
  ///         }
  ///       }
  ///     }
  ///   ],
  ///   "theme": {
  ///     "name": "Default",
  ///     "uuid": "f5468354-01fb-44d8-b7b3-5ede94c6115c",
  ///     "index": 0
  ///   }
  /// }
  /// ```
  ///
  /// ## RESPONSE 200:
  ///
  /// The request was processed successfully.
  ///
  /// content-type: `application/json`
  ///
  /// schema:
  /// ```json
  /// {
  ///   "type": "object",
  ///   "required": [
  ///     "id",
  ///     "message",
  ///     "theme"
  ///   ],
  ///   "example": {
  ///     "id": {
  ///       "name": "Test Message",
  ///       "uuid": "942C3FC3-C4B2-44F7-A55D-4CC913BB8A5D",
  ///       "index": 0
  ///     },
  ///     "message": "Text {text}, Clock {System Clock}, Countdown {Timer 1}, Countdown to time {Timer 2}, Elapsed {Timer 3}",
  ///     "tokens": [
  ///       {
  ///         "name": "text",
  ///         "text": {
  ///           "text": "142"
  ///         }
  ///       },
  ///       {
  ///         "name": "System Clock",
  ///         "clock": {
  ///           "format": {
  ///             "date": "short",
  ///             "time": "long",
  ///             "is_24_hours": true
  ///           }
  ///         }
  ///       },
  ///       {
  ///         "name": "Timer 1",
  ///         "timer": {
  ///           "configuration": {
  ///             "id": {
  ///               "name": "Timer 1",
  ///               "uuid": "43b4c5c6-145a-4b19-9968-7b78e6980e82",
  ///               "index": 0
  ///             },
  ///             "allows_overrun": true,
  ///             "countdown": {
  ///               "duration": 300
  ///             }
  ///           },
  ///           "format": {
  ///             "hour": "remove_long",
  ///             "minute": "remove_long",
  ///             "second": "short",
  ///             "millisecond": "none"
  ///           }
  ///         }
  ///       },
  ///       {
  ///         "name": "Timer 2",
  ///         "timer": {
  ///           "configuration": {
  ///             "id": {
  ///               "name": "Timer 2",
  ///               "uuid": "1355b458-5f99-4e6e-8ac7-8522061f6bdb",
  ///               "index": 0
  ///             },
  ///             "allows_overrun": true,
  ///             "count_down_to_time": {
  ///               "time_of_day": "09:30",
  ///               "period": "am"
  ///             }
  ///           },
  ///           "format": {
  ///             "hour": "remove_long",
  ///             "minute": "remove_long",
  ///             "second": "short",
  ///             "millisecond": "none"
  ///           }
  ///         }
  ///       },
  ///       {
  ///         "name": "Timer 3",
  ///         "timer": {
  ///           "configuration": {
  ///             "id": {
  ///               "name": "Timer 3",
  ///               "uuid": "8efe5ec8-daf4-4609-aea2-7c80efa7f6fa",
  ///               "index": 0
  ///             },
  ///             "allows_overrun": true,
  ///             "elapsed": {
  ///               "start_time": 0
  ///             }
  ///           },
  ///           "format": {
  ///             "hour": "remove_long",
  ///             "minute": "remove_long",
  ///             "second": "short",
  ///             "millisecond": "none"
  ///           }
  ///         }
  ///       }
  ///     ],
  ///     "theme": {
  ///       "name": "Default",
  ///       "uuid": "f5468354-01fb-44d8-b7b3-5ede94c6115c",
  ///       "index": 0
  ///     }
  ///   }
  /// }
  /// ```
  ///
  /// ## RESPONSE 400:
  ///
  /// The request was not valid.
  ///
  /// content-type: ``
  ///
  static Future<Map<String, dynamic>> messageCreate(Map postBody) async {
    String url = '/v1/messages';

    return await call('post', url);
  }

  /// `messageGet` -> `/v1/message/{id}`
  ///
  /// Requests the details of the specified message.
  ///
  ///
  /// ## PARAMETERS
  /// [id] (required) :
  /// The ID of the message, either UUID, name, or index.
  ///
  /// - Example (by_uuid): `3C39C433-5C18-4F51-B357-55BB870227C4`
  /// - Example (by_name): `Mask`
  /// - Example (by_index): `3`
  ///
  /// ## RESPONSE 200:
  ///
  /// The request was processed successfully.
  ///
  /// content-type: `application/json`
  ///
  /// schema:
  /// ```json
  /// {
  ///   "type": "object",
  ///   "required": [
  ///     "id",
  ///     "message",
  ///     "theme"
  ///   ],
  ///   "example": {
  ///     "id": {
  ///       "name": "Test Message",
  ///       "uuid": "942C3FC3-C4B2-44F7-A55D-4CC913BB8A5D",
  ///       "index": 0
  ///     },
  ///     "message": "Text {text}, Clock {System Clock}, Countdown {Timer 1}, Countdown to time {Timer 2}, Elapsed {Timer 3}",
  ///     "tokens": [
  ///       {
  ///         "name": "text",
  ///         "text": {
  ///           "text": "142"
  ///         }
  ///       },
  ///       {
  ///         "name": "System Clock",
  ///         "clock": {
  ///           "format": {
  ///             "date": "short",
  ///             "time": "long",
  ///             "is_24_hours": true
  ///           }
  ///         }
  ///       },
  ///       {
  ///         "name": "Timer 1",
  ///         "timer": {
  ///           "configuration": {
  ///             "id": {
  ///               "name": "Timer 1",
  ///               "uuid": "43b4c5c6-145a-4b19-9968-7b78e6980e82",
  ///               "index": 0
  ///             },
  ///             "allows_overrun": true,
  ///             "countdown": {
  ///               "duration": 300
  ///             }
  ///           },
  ///           "format": {
  ///             "hour": "remove_long",
  ///             "minute": "remove_long",
  ///             "second": "short",
  ///             "millisecond": "none"
  ///           }
  ///         }
  ///       },
  ///       {
  ///         "name": "Timer 2",
  ///         "timer": {
  ///           "configuration": {
  ///             "id": {
  ///               "name": "Timer 2",
  ///               "uuid": "1355b458-5f99-4e6e-8ac7-8522061f6bdb",
  ///               "index": 0
  ///             },
  ///             "allows_overrun": true,
  ///             "count_down_to_time": {
  ///               "time_of_day": "09:30",
  ///               "period": "am"
  ///             }
  ///           },
  ///           "format": {
  ///             "hour": "remove_long",
  ///             "minute": "remove_long",
  ///             "second": "short",
  ///             "millisecond": "none"
  ///           }
  ///         }
  ///       },
  ///       {
  ///         "name": "Timer 3",
  ///         "timer": {
  ///           "configuration": {
  ///             "id": {
  ///               "name": "Timer 3",
  ///               "uuid": "8efe5ec8-daf4-4609-aea2-7c80efa7f6fa",
  ///               "index": 0
  ///             },
  ///             "allows_overrun": true,
  ///             "elapsed": {
  ///               "start_time": 0
  ///             }
  ///           },
  ///           "format": {
  ///             "hour": "remove_long",
  ///             "minute": "remove_long",
  ///             "second": "short",
  ///             "millisecond": "none"
  ///           }
  ///         }
  ///       }
  ///     ],
  ///     "theme": {
  ///       "name": "Default",
  ///       "uuid": "f5468354-01fb-44d8-b7b3-5ede94c6115c",
  ///       "index": 0
  ///     }
  ///   }
  /// }
  /// ```
  static Future<Map<String, dynamic>> messageGet(String id) async {
    String url = '/v1/message/$id';

    return await call('get', url);
  }

  /// `messageSet` -> `/v1/message/{id}`
  ///
  /// Sets the details of the specified message.
  ///
  ///
  /// ## PARAMETERS
  /// [id] (required) :
  /// The ID of the message, either UUID, name, or index.
  ///
  /// - Example (by_uuid): `3C39C433-5C18-4F51-B357-55BB870227C4`
  /// - Example (by_name): `Mask`
  /// - Example (by_index): `3`
  ///
  /// [postBody] (required) : This is the data that must be sent with this request.
  ///
  /// Example:
  /// ```json
  /// {
  ///   "id": {
  ///     "name": "Test Message",
  ///     "uuid": "942C3FC3-C4B2-44F7-A55D-4CC913BB8A5D",
  ///     "index": 0
  ///   },
  ///   "message": "Text {text}, Clock {System Clock}, Countdown {Timer 1}, Countdown to time {Timer 2}, Elapsed {Timer 3}",
  ///   "tokens": [
  ///     {
  ///       "name": "text",
  ///       "text": {
  ///         "text": "142"
  ///       }
  ///     },
  ///     {
  ///       "name": "System Clock",
  ///       "clock": {
  ///         "format": {
  ///           "date": "short",
  ///           "time": "long",
  ///           "is_24_hours": true
  ///         }
  ///       }
  ///     },
  ///     {
  ///       "name": "Timer 1",
  ///       "timer": {
  ///         "configuration": {
  ///           "id": {
  ///             "name": "Timer 1",
  ///             "uuid": "43b4c5c6-145a-4b19-9968-7b78e6980e82",
  ///             "index": 0
  ///           },
  ///           "allows_overrun": true,
  ///           "countdown": {
  ///             "duration": 300
  ///           }
  ///         },
  ///         "format": {
  ///           "hour": "remove_long",
  ///           "minute": "remove_long",
  ///           "second": "short",
  ///           "millisecond": "none"
  ///         }
  ///       }
  ///     },
  ///     {
  ///       "name": "Timer 2",
  ///       "timer": {
  ///         "configuration": {
  ///           "id": {
  ///             "name": "Timer 2",
  ///             "uuid": "1355b458-5f99-4e6e-8ac7-8522061f6bdb",
  ///             "index": 0
  ///           },
  ///           "allows_overrun": true,
  ///           "count_down_to_time": {
  ///             "time_of_day": "09:30",
  ///             "period": "am"
  ///           }
  ///         },
  ///         "format": {
  ///           "hour": "remove_long",
  ///           "minute": "remove_long",
  ///           "second": "short",
  ///           "millisecond": "none"
  ///         }
  ///       }
  ///     },
  ///     {
  ///       "name": "Timer 3",
  ///       "timer": {
  ///         "configuration": {
  ///           "id": {
  ///             "name": "Timer 3",
  ///             "uuid": "8efe5ec8-daf4-4609-aea2-7c80efa7f6fa",
  ///             "index": 0
  ///           },
  ///           "allows_overrun": true,
  ///           "elapsed": {
  ///             "start_time": 0
  ///           }
  ///         },
  ///         "format": {
  ///           "hour": "remove_long",
  ///           "minute": "remove_long",
  ///           "second": "short",
  ///           "millisecond": "none"
  ///         }
  ///       }
  ///     }
  ///   ],
  ///   "theme": {
  ///     "name": "Default",
  ///     "uuid": "f5468354-01fb-44d8-b7b3-5ede94c6115c",
  ///     "index": 0
  ///   }
  /// }
  /// ```
  ///
  /// Example (text_token):
  ///
  /// ```json
  /// {
  ///   "id": {
  ///     "name": "Message with text token",
  ///     "uuid": "",
  ///     "index": 0
  ///   },
  ///   "message": "Please come to room {room}",
  ///   "tokens": [
  ///     {
  ///       "name": "room",
  ///       "text": {
  ///         "text": "142"
  ///       }
  ///     }
  ///   ],
  ///   "theme": {
  ///     "name": "",
  ///     "uuid": "",
  ///     "index": 0
  ///   }
  /// }
  /// ```
  /// Example (clock_token):
  ///
  /// ```json
  /// {
  ///   "id": {
  ///     "name": "Message with clock token",
  ///     "uuid": "",
  ///     "index": 0
  ///   },
  ///   "message": "The current time is {time}",
  ///   "tokens": [
  ///     {
  ///       "name": "time",
  ///       "clock": {
  ///         "format": {
  ///           "date": "short",
  ///           "time": "long",
  ///           "is_24_hours": true
  ///         }
  ///       }
  ///     }
  ///   ],
  ///   "theme": {
  ///     "name": "",
  ///     "uuid": "",
  ///     "index": 0
  ///   }
  /// }
  /// ```
  /// Example (timer_token_countdown):
  ///
  /// ```json
  /// {
  ///   "id": {
  ///     "name": "Message with countdown timer token",
  ///     "uuid": "",
  ///     "index": 0
  ///   },
  ///   "message": "Time until start: {Timer Token}",
  ///   "tokens": [
  ///     {
  ///       "name": "Timer Token",
  ///       "timer": {
  ///         "id": {
  ///           "name": "Countdown Timer",
  ///           "uuid": "942C3FC3-C4B2-44F7-A55D-4CC913BB8A5D",
  ///           "index": 1
  ///         },
  ///         "allows_overrun": true,
  ///         "format": {
  ///           "hour": "remove_long",
  ///           "minute": "remove_long",
  ///           "second": "short",
  ///           "millisecond": "none"
  ///         },
  ///         "countdown": {
  ///           "duration": 300
  ///         }
  ///       }
  ///     }
  ///   ],
  ///   "theme": {
  ///     "name": "",
  ///     "uuid": "",
  ///     "index": 0
  ///   }
  /// }
  /// ```
  /// Example (timer_token_countdown_to_time):
  ///
  /// ```json
  /// {
  ///   "id": {
  ///     "name": "Message with countdown to time timer token",
  ///     "uuid": "",
  ///     "index": 0
  ///   },
  ///   "message": "Time until start: {Timer Token}",
  ///   "tokens": [
  ///     {
  ///       "name": "Timer Token",
  ///       "timer": {
  ///         "id": {
  ///           "name": "Count Down to Time Timer",
  ///           "uuid": "942C3FC3-C4B2-44F7-A55D-4CC913BB8A5D",
  ///           "index": 1
  ///         },
  ///         "allows_overrun": true,
  ///         "format": {
  ///           "hour": "remove_long",
  ///           "minute": "remove_long",
  ///           "second": "short",
  ///           "millisecond": "none"
  ///         },
  ///         "count_down_to_time": {
  ///           "time_of_day": 3600,
  ///           "period": "pm"
  ///         }
  ///       }
  ///     }
  ///   ],
  ///   "theme": {
  ///     "name": "",
  ///     "uuid": "",
  ///     "index": 0
  ///   }
  /// }
  /// ```
  /// Example (timer_token_elapsed):
  ///
  /// ```json
  /// {
  ///   "id": {
  ///     "name": "Message with elapsed timer token",
  ///     "uuid": "",
  ///     "index": 0
  ///   },
  ///   "message": "Time since start: {Timer Token}",
  ///   "tokens": [
  ///     {
  ///       "name": "Timer Token",
  ///       "timer": {
  ///         "id": {
  ///           "name": "Elapsed Timer",
  ///           "uuid": "942C3FC3-C4B2-44F7-A55D-4CC913BB8A5D",
  ///           "index": 1
  ///         },
  ///         "allows_overrun": true,
  ///         "format": {
  ///           "hour": "remove_long",
  ///           "minute": "remove_long",
  ///           "second": "short",
  ///           "millisecond": "none"
  ///         },
  ///         "elapsed": {
  ///           "start_time": 0,
  ///           "end_time": 60
  ///         }
  ///       }
  ///     }
  ///   ],
  ///   "theme": {
  ///     "name": "",
  ///     "uuid": "",
  ///     "index": 0
  ///   }
  /// }
  /// ```
  ///
  /// ## RESPONSE 200:
  ///
  /// The request was processed successfully.
  ///
  /// content-type: `application/json`
  ///
  /// schema:
  /// ```json
  /// {
  ///   "type": "object",
  ///   "required": [
  ///     "id",
  ///     "message",
  ///     "theme"
  ///   ],
  ///   "example": {
  ///     "id": {
  ///       "name": "Test Message",
  ///       "uuid": "942C3FC3-C4B2-44F7-A55D-4CC913BB8A5D",
  ///       "index": 0
  ///     },
  ///     "message": "Text {text}, Clock {System Clock}, Countdown {Timer 1}, Countdown to time {Timer 2}, Elapsed {Timer 3}",
  ///     "tokens": [
  ///       {
  ///         "name": "text",
  ///         "text": {
  ///           "text": "142"
  ///         }
  ///       },
  ///       {
  ///         "name": "System Clock",
  ///         "clock": {
  ///           "format": {
  ///             "date": "short",
  ///             "time": "long",
  ///             "is_24_hours": true
  ///           }
  ///         }
  ///       },
  ///       {
  ///         "name": "Timer 1",
  ///         "timer": {
  ///           "configuration": {
  ///             "id": {
  ///               "name": "Timer 1",
  ///               "uuid": "43b4c5c6-145a-4b19-9968-7b78e6980e82",
  ///               "index": 0
  ///             },
  ///             "allows_overrun": true,
  ///             "countdown": {
  ///               "duration": 300
  ///             }
  ///           },
  ///           "format": {
  ///             "hour": "remove_long",
  ///             "minute": "remove_long",
  ///             "second": "short",
  ///             "millisecond": "none"
  ///           }
  ///         }
  ///       },
  ///       {
  ///         "name": "Timer 2",
  ///         "timer": {
  ///           "configuration": {
  ///             "id": {
  ///               "name": "Timer 2",
  ///               "uuid": "1355b458-5f99-4e6e-8ac7-8522061f6bdb",
  ///               "index": 0
  ///             },
  ///             "allows_overrun": true,
  ///             "count_down_to_time": {
  ///               "time_of_day": "09:30",
  ///               "period": "am"
  ///             }
  ///           },
  ///           "format": {
  ///             "hour": "remove_long",
  ///             "minute": "remove_long",
  ///             "second": "short",
  ///             "millisecond": "none"
  ///           }
  ///         }
  ///       },
  ///       {
  ///         "name": "Timer 3",
  ///         "timer": {
  ///           "configuration": {
  ///             "id": {
  ///               "name": "Timer 3",
  ///               "uuid": "8efe5ec8-daf4-4609-aea2-7c80efa7f6fa",
  ///               "index": 0
  ///             },
  ///             "allows_overrun": true,
  ///             "elapsed": {
  ///               "start_time": 0
  ///             }
  ///           },
  ///           "format": {
  ///             "hour": "remove_long",
  ///             "minute": "remove_long",
  ///             "second": "short",
  ///             "millisecond": "none"
  ///           }
  ///         }
  ///       }
  ///     ],
  ///     "theme": {
  ///       "name": "Default",
  ///       "uuid": "f5468354-01fb-44d8-b7b3-5ede94c6115c",
  ///       "index": 0
  ///     }
  ///   }
  /// }
  /// ```
  ///
  /// ## RESPONSE 400:
  ///
  /// The request was not valid.
  ///
  /// content-type: ``
  ///
  static Future<Map<String, dynamic>> messageSet(String id, Map postBody) async {
    String url = '/v1/message/$id';

    return await call('put', url);
  }

  /// `messaageDelete` -> `/v1/message/{id}`
  ///
  /// Deletes the specified message.
  ///
  ///
  /// ## PARAMETERS
  /// [id] (required) :
  /// The ID of the message, either UUID, name, or index.
  ///
  /// - Example (by_uuid): `3C39C433-5C18-4F51-B357-55BB870227C4`
  /// - Example (by_name): `Mask`
  /// - Example (by_index): `3`
  ///
  /// ## RESPONSE 204:
  ///
  /// The request was processed successfully. There is no response body.
  ///
  /// content-type: `NONE`
  ///
  static Future<Uint8List> messaageDelete(String id) async {
    String url = '/v1/message/$id';

    return await call('delete', url);
  }

  /// `messageTrigger` -> `/v1/message/{id}/trigger`
  ///
  /// Triggers / Shows the specified message.
  ///
  ///
  /// ## PARAMETERS
  ///
  /// [id] : The ID of the message, either UUID, name, or index.
  ///
  /// - Example (by_uuid): `3C39C433-5C18-4F51-B357-55BB870227C4`
  /// - Example (by_name): `Mask`
  /// - Example (by_index): `3`
  ///
  /// [postBody] (optional) : This is the data that can be sent with this request.
  ///
  /// Example (trigger_message):
  ///
  /// ```json
  /// [
  ///   {
  ///     "name": "My Text Token",
  ///     "text": {
  ///       "text": "Hello, world!"
  ///     }
  ///   },
  ///   {
  ///     "name": "Countdown Timer",
  ///     "timer": {
  ///       "configuration": {
  ///         "allows_overrun": true,
  ///         "countdown": {
  ///           "duration": 3600
  ///         },
  ///         "format": {
  ///           "hour": "none",
  ///           "minute": "short",
  ///           "second": "long",
  ///           "millisecond": "remove_short"
  ///         }
  ///       }
  ///     }
  ///   },
  ///   {
  ///     "name": "Countdown To Time",
  ///     "timer": {
  ///       "configuration": {
  ///         "allows_overrun": true,
  ///         "count_down_to_time": {
  ///           "time_of_day": 1800,
  ///           "period": "pm"
  ///         },
  ///         "format": {
  ///           "hour": "long",
  ///           "minute": "long",
  ///           "second": "none",
  ///           "millisecond": "none"
  ///         }
  ///       }
  ///     }
  ///   },
  ///   {
  ///     "name": "Elapsed Timer",
  ///     "timer": {
  ///       "configuration": {
  ///         "allows_overrun": false,
  ///         "elapsed": {
  ///           "start_time": 0,
  ///           "end_time": 300
  ///         },
  ///         "format": {
  ///           "hour": "none",
  ///           "minute": "short",
  ///           "second": "long",
  ///           "millisecond": "none"
  ///         }
  ///       }
  ///     }
  ///   },
  ///   {
  ///     "name": "My Clock Token",
  ///     "clock": {
  ///       "format": {
  ///         "date": "full",
  ///         "time": "short",
  ///         "is_24_hours": false
  ///       }
  ///     }
  ///   }
  /// ]
  /// ```
  ///
  /// ## RESPONSE 204:
  ///
  /// The request was processed successfully. There is no response body.
  ///
  /// content-type: `NONE`
  ///
  /// ## RESPONSE 400:
  ///
  /// The request was not valid.
  ///
  /// content-type: ``
  ///
  static Future<Uint8List> messageTrigger(String id, List postBody) async {
    String url = '/v1/message/$id/trigger';

    return await call('post', url);
  }

  /// `messageClear` -> `/v1/message/{id}/clear`
  ///
  /// Clears / Hides the specified message.
  ///
  ///
  /// ## PARAMETERS
  ///
  /// [id] : The ID of the message, either UUID, name, or index.
  ///
  /// - Example (by_uuid): `3C39C433-5C18-4F51-B357-55BB870227C4`
  /// - Example (by_name): `Mask`
  /// - Example (by_index): `3`
  ///
  /// ## RESPONSE 204:
  ///
  /// The request was processed successfully. There is no response body.
  ///
  /// content-type: `NONE`
  ///
  /// ## RESPONSE 400:
  ///
  /// The request was not valid.
  ///
  /// content-type: ``
  ///
  static Future<Uint8List> messageClear(String id) async {
    String url = '/v1/message/$id/clear';

    return await call('get', url);
  }

  /// `findMyMouse` -> `/v1/find_my_mouse`
  ///
  /// Executes the "Find My Mouse" operation.
  ///
  ///
  /// ## RESPONSE 204:
  ///
  /// The request was processed successfully. There is no response body.
  ///
  /// content-type: `NONE`
  ///
  static Future<Uint8List> findMyMouse() async {
    String url = '/v1/findMyMouse';

    return await call('get', url);
  }

  /// `playlistGetAll` -> `/v1/playlists`
  ///
  /// Requests a list of all configured playlists.
  ///
  ///
  /// ## RESPONSE 200:
  ///
  /// The request was processed successfully.
  ///
  /// content-type: `application/json`
  ///
  /// schema:
  /// ```json
  /// {
  ///   "type": "array",
  ///   "required": []
  /// }
  /// ```
  static Future<Map<String, dynamic>> playlistGetAll() async {
    String url = '/v1/playlists';

    return await call('get', url);
  }

  /// `playlistCreateTopLevel` -> `/v1/playlists`
  ///
  /// Creates a playlist with the specified details.
  ///
  ///
  /// ## PARAMETERS
  ///
  /// [postBody] (required) : This is the data that must be sent with this request.
  ///
  /// Example (playlist):
  ///
  /// ```json
  /// {
  ///   "name": "Sunday Service",
  ///   "type": "playlist"
  /// }
  /// ```
  /// Example (group):
  ///
  /// ```json
  /// {
  ///   "name": "Evening Services",
  ///   "type": "group"
  /// }
  /// ```
  ///
  /// ## RESPONSE 200:
  ///
  /// The request was processed successfully.
  ///
  /// content-type: `application/json`
  ///
  /// schema:
  /// ```json
  /// {
  ///   "oneOf": [
  ///     {
  ///       "type": "object",
  ///       "required": [
  ///         "id",
  ///         "type",
  ///         "playlists"
  ///       ]
  ///     },
  ///     {
  ///       "type": "object",
  ///       "required": [
  ///         "id",
  ///         "type"
  ///       ]
  ///     }
  ///   ]
  /// }
  /// ```
  ///
  /// ## RESPONSE 400:
  ///
  /// The request was not valid.
  ///
  /// content-type: ``
  ///
  static Future<Map<String, dynamic>> playlistCreateTopLevel(Map postBody) async {
    String url = '/v1/playlists';

    return await call('post', url);
  }

  /// `playlistActiveGet` -> `/v1/playlist/active`
  ///
  /// Requests the details of the active playlist.
  ///
  ///
  /// ## RESPONSE 200:
  ///
  /// The response was processed successfully.
  ///
  /// content-type: `application/json`
  ///
  /// schema:
  /// ```json
  /// {
  ///   "type": "object",
  ///   "required": [
  ///     "presentation",
  ///     "announcements"
  ///   ]
  /// }
  /// ```
  static Future<Map<String, dynamic>> playlistActiveGet() async {
    String url = '/v1/playlist/active';

    return await call('get', url);
  }

  /// Streaming version of [playlistActiveGet]
  static Future<Stream?> playlistActiveGetStream() async {
    String url = '/v1/playlist/active';

    var uri = Uri.http('$host:$port', url, {'chunked': 'true'});
    return ChunkedJsonClient.request(uri);
  }

  /// `playlistGet` -> `/v1/playlist/{playlist_id}`
  ///
  /// Requests a list of the items in the specified playlist.
  ///
  ///
  /// ## PARAMETERS
  /// [playlistId] (required) :
  /// The ID of the playlist, either UUID, name, or index, in order of interpretation and search priority. A path can also be specified to identify playlists within folders. UUID and name matches are searched through the entire playlist tree. Because UUIDs are unique a path is not necessary. A name path is not necessary unless there are multiple playlists with the same name in different folders. A partial path of names can be used as well. Indices only index into the immediate children at each level of the tree so an index path is requred to access playlists within folders if only using indices. A mix of UUIDs, names, and indices can be used for the path if desired.
  ///
  /// - Example (by_uuid): `3C39C433-5C18-4F51-B357-55BB870227C4`
  /// - Example (by_name): `Playlist Name`
  /// - Example (by_name_with_path): `Folder1/Folder2/Playlist Name`
  /// - Example (by_index): `3`
  /// - Example (by_index_path): `2/0/1`
  /// - Example (by_mixed_path): `3C39C433-5C18-4F51-B357-55BB870227C4/Folder Name/0`
  ///
  /// ## RESPONSE 200:
  ///
  /// The request was processed successfully.
  ///
  /// content-type: `application/json`
  ///
  /// schema:
  /// ```json
  /// {
  ///   "type": "object",
  ///   "required": [
  ///     "id",
  ///     "items"
  ///   ],
  ///   "example": {
  ///     "id": {
  ///       "index": 0,
  ///       "name": "Sunday Service",
  ///       "uuid": "942C3FC3-C4B2-44F7-A55D-4CC913BB8A5A"
  ///     },
  ///     "items": [
  ///       {
  ///         "id": {
  ///           "index": 0,
  ///           "name": "Songs",
  ///           "uuid": ""
  ///         },
  ///         "type": "header",
  ///         "is_hidden": true,
  ///         "is_pco": false,
  ///         "header_color": {
  ///           "red": 0,
  ///           "green": 0.54,
  ///           "blue": 0.87,
  ///           "alpha": 1
  ///         }
  ///       },
  ///       {
  ///         "id": {
  ///           "index": 1,
  ///           "name": "Amazing Grace",
  ///           "uuid": "942C3FC3-C4B2-44F7-A55D-4CC913BB8A5B"
  ///         },
  ///         "type": "presentation",
  ///         "is_hidden": false,
  ///         "is_pco": false
  ///       },
  ///       {
  ///         "id": {
  ///           "index": 2,
  ///           "name": "Graves Into Gardens",
  ///           "uuid": "942C3FC3-C4B2-44F7-A55D-4CC913BB8A5C"
  ///         },
  ///         "type": "presentation",
  ///         "is_hidden": false,
  ///         "is_pco": false
  ///       },
  ///       {
  ///         "id": {
  ///           "index": 3,
  ///           "name": "Sermon",
  ///           "uuid": ""
  ///         },
  ///         "type": "header",
  ///         "is_hidden": false,
  ///         "is_pco": false,
  ///         "header_color": {
  ///           "red": 0.87,
  ///           "green": 0,
  ///           "blue": 0.54,
  ///           "alpha": 1
  ///         }
  ///       },
  ///       {
  ///         "id": {
  ///           "index": 4,
  ///           "name": "Sermon Notes 2022-01-16",
  ///           "uuid": "942C3FC3-C4B2-44F7-A55D-4CC913BB8A5D"
  ///         },
  ///         "type": "presentation",
  ///         "is_hidden": false,
  ///         "is_pco": false
  ///       }
  ///     ]
  ///   }
  /// }
  /// ```
  static Future<Map<String, dynamic>> playlistGet(String playlistId) async {
    String url = '/v1/playlist/$playlistId';

    return await call('get', url);
  }

  /// `playlistPut` -> `/v1/playlist/{playlist_id}`
  ///
  /// Sets the contents of the specified playlist.
  ///
  ///
  /// ## PARAMETERS
  /// [playlistId] (required) :
  /// The ID of the playlist, either UUID, name, or index, in order of interpretation and search priority. A path can also be specified to identify playlists within folders. UUID and name matches are searched through the entire playlist tree. Because UUIDs are unique a path is not necessary. A name path is not necessary unless there are multiple playlists with the same name in different folders. A partial path of names can be used as well. Indices only index into the immediate children at each level of the tree so an index path is requred to access playlists within folders if only using indices. A mix of UUIDs, names, and indices can be used for the path if desired.
  ///
  /// - Example (by_uuid): `3C39C433-5C18-4F51-B357-55BB870227C4`
  /// - Example (by_name): `Playlist Name`
  /// - Example (by_name_with_path): `Folder1/Folder2/Playlist Name`
  /// - Example (by_index): `3`
  /// - Example (by_index_path): `2/0/1`
  /// - Example (by_mixed_path): `3C39C433-5C18-4F51-B357-55BB870227C4/Folder Name/0`
  ///
  /// [postBody] (required) : This is the data that must be sent with this request.
  ///
  /// Example:
  ///
  /// ```json
  /// [
  ///   {
  ///     "id": {
  ///       "uuid": "942C3FC3-C4B2-44F7-A55D-4CC913BB8A5C",
  ///       "name": "Announcements",
  ///       "index": 0
  ///     },
  ///     "type": "media",
  ///     "is_hidden": true,
  ///     "is_pco": false
  ///   },
  ///   {
  ///     "id": {
  ///       "uuid": null,
  ///       "name": "Songs",
  ///       "index": 1
  ///     },
  ///     "type": "header",
  ///     "header_color": {
  ///       "red": 0,
  ///       "green": 0.54,
  ///       "blue": 0.87,
  ///       "alpha": 1
  ///     },
  ///     "is_hidden": false,
  ///     "is_pco": false
  ///   },
  ///   {
  ///     "id": {
  ///       "uuid": "942C3FC3-C4B2-44F7-A55D-4CC913BB8A5D",
  ///       "name": "Amazing Grace",
  ///       "index": 2
  ///     },
  ///     "type": "presentation",
  ///     "is_hidden": false,
  ///     "is_pco": false
  ///   }
  /// ]
  /// ```
  ///
  /// ## RESPONSE 204:
  ///
  /// The request was processed successfully. There is no response body.
  ///
  /// content-type: `NONE`
  ///
  /// ## RESPONSE 400:
  ///
  /// The request was not valid.
  ///
  /// content-type: ``
  ///
  static Future<Uint8List> playlistPut(String playlistId, List postBody) async {
    String url = '/v1/playlist/$playlistId';

    return await call('put', url);
  }

  /// `playlistCreate` -> `/v1/playlist/{playlist_id}`
  ///
  /// Creates a playlist with the specified details underneath the specified playlist or playlist folder.
  ///
  ///
  /// ## PARAMETERS
  /// [playlistId] (required) :
  /// The ID of the playlist, either UUID, name, or index, in order of interpretation and search priority. A path can also be specified to identify playlists within folders. UUID and name matches are searched through the entire playlist tree. Because UUIDs are unique a path is not necessary. A name path is not necessary unless there are multiple playlists with the same name in different folders. A partial path of names can be used as well. Indices only index into the immediate children at each level of the tree so an index path is requred to access playlists within folders if only using indices. A mix of UUIDs, names, and indices can be used for the path if desired.
  ///
  /// - Example (by_uuid): `3C39C433-5C18-4F51-B357-55BB870227C4`
  /// - Example (by_name): `Playlist Name`
  /// - Example (by_name_with_path): `Folder1/Folder2/Playlist Name`
  /// - Example (by_index): `3`
  /// - Example (by_index_path): `2/0/1`
  /// - Example (by_mixed_path): `3C39C433-5C18-4F51-B357-55BB870227C4/Folder Name/0`
  ///
  /// [postBody] (required) : This is the data that must be sent with this request.
  ///
  /// Example (playlist):
  ///
  /// ```json
  /// {
  ///   "name": "Sunday Service",
  ///   "type": "playlist"
  /// }
  /// ```
  /// Example (group):
  ///
  /// ```json
  /// {
  ///   "name": "Evening Services",
  ///   "type": "group"
  /// }
  /// ```
  ///
  /// ## RESPONSE 200:
  ///
  /// The request was processed successfully.
  ///
  /// content-type: `application/json`
  ///
  /// schema:
  /// ```json
  /// {
  ///   "oneOf": [
  ///     {
  ///       "type": "object",
  ///       "required": [
  ///         "id",
  ///         "type",
  ///         "playlists"
  ///       ]
  ///     },
  ///     {
  ///       "type": "object",
  ///       "required": [
  ///         "id",
  ///         "type"
  ///       ]
  ///     }
  ///   ]
  /// }
  /// ```
  ///
  /// ## RESPONSE 400:
  ///
  /// The request was not valid.
  ///
  /// content-type: ``
  ///
  static Future<Map<String, dynamic>> playlistCreate(String playlistId, Map postBody) async {
    String url = '/v1/playlist/$playlistId';

    return await call('post', url);
  }

  /// `presentationGetActive` -> `/v1/presentation/current`
  ///
  /// Requests the details of the currently active presentation.
  ///
  ///
  /// ## RESPONSE 200:
  ///
  /// The request was processed successfully.
  ///
  /// content-type: `application/json`
  ///
  /// schema:
  /// ```json
  /// {
  ///   "type": "object",
  ///   "required": []
  /// }
  /// ```
  static Future<Map<String, dynamic>> presentationGetActive() async {
    String url = '/v1/presentation/current';

    return await call('get', url);
  }

  /// Streaming version of [presentationGetActive]
  static Future<Stream?> presentationGetActiveStream() async {
    String url = '/v1/presentation/current';

    var uri = Uri.http('$host:$port', url, {'chunked': 'true'});
    return ChunkedJsonClient.request(uri);
  }

  /// `presentationGetSlideIndex` -> `/v1/presentation/slide_index`
  ///
  /// Requests the index of the current slide/cue within the currently active presentation.
  ///
  ///
  /// ## RESPONSE 200:
  ///
  /// The request was processed successfully.
  ///
  /// content-type: `application/json`
  ///
  /// schema:
  /// ```json
  /// {
  ///   "type": "object",
  ///   "required": []
  /// }
  /// ```
  static Future<Map<String, dynamic>> presentationGetSlideIndex() async {
    String url = '/v1/presentation/slideIndex';

    return await call('get', url);
  }

  /// Streaming version of [presentationGetSlideIndex]
  static Future<Stream?> presentationGetSlideIndexStream() async {
    String url = '/v1/presentation/slideIndex';

    var uri = Uri.http('$host:$port', url, {'chunked': 'true'});
    return ChunkedJsonClient.request(uri);
  }

  /// `presentationGetChordChart` -> `/v1/presentation/chord_chart`
  ///
  /// Requests the current chord chart image (if available) at the given quality value.
  ///
  ///
  /// ## PARAMETERS
  ///
  /// [quality] : The desired quality of the thumbnail. The value is the number of pixels in the _largest_ dimension of the image,
  /// i.e. if the image is landscape (wider than it is tall), it is the _width_ of the image. If the image is portrait
  /// (taller than it is wide), it is the _height_ of the image.
  ///
  /// Example: `400`
  ///
  /// ## RESPONSE 200:
  ///
  /// The request was processed successfully.
  ///
  /// content-type: `image/jpeg`
  ///
  /// schema:
  /// ```json
  /// {
  ///   "type": "string",
  ///   "required": [],
  ///   "format": "binary",
  ///   "example": "image data here"
  /// }
  /// ```
  static Future<Uint8List> presentationGetChordChart({int? quality}) async {
    String url = '/v1/presentation/chordChart';
    Map<String, dynamic> query = {'quality': quality.toString()};

    return await call('get', url, params: query);
  }

  /// `presentationGetChordChartUpdates` -> `/v1/presentation/chord_chart/updates`
  ///
  /// Requests a chunked data update every time the chord chart changes.
  ///
  ///
  /// ## RESPONSE 200:
  ///
  /// The request was processed successfully.
  ///
  /// content-type: `application/json`
  ///
  /// schema:
  /// ```json
  /// {
  ///   "type": "string",
  ///   "required": [],
  ///   "enum": [
  ///     "change"
  ///   ]
  /// }
  /// ```
  static Future<Map<String, dynamic>> presentationGetChordChartUpdates() async {
    String url = '/v1/presentation/chordChart/updates';

    return await call('get', url);
  }

  /// Streaming version of [presentationGetChordChartUpdates]
  static Future<Stream?> presentationGetChordChartUpdatesStream() async {
    String url = '/v1/presentation/chordChart/updates';

    var uri = Uri.http('$host:$port', url, {'chunked': 'true'});
    return ChunkedJsonClient.request(uri);
  }

  /// `presentationGet` -> `/v1/presentation/{uuid}`
  ///
  /// Requests the details of the specified presentation.
  ///
  ///
  /// ## PARAMETERS
  ///
  /// [uuid] : The UUID of the presentation to look up.
  ///
  /// - Example (uuid): `3C39C433-5C18-4F51-B357-55BB870227C4`
  ///
  /// ## RESPONSE 200:
  ///
  /// The request was processed successfully.
  ///
  /// content-type: `application/json`
  ///
  /// schema:
  /// ```json
  /// {
  ///   "type": "object",
  ///   "required": [
  ///     "groups",
  ///     "name",
  ///     "has_timeline",
  ///     "current_location",
  ///     "destination"
  ///   ]
  /// }
  /// ```
  static Future<Map<String, dynamic>> presentationGet(String uuid) async {
    String url = '/v1/presentation/$uuid';

    return await call('get', url);
  }

  /// `presentationTrigger` -> `/v1/presentation/{uuid}/trigger`
  ///
  /// Triggers the specified presentation.
  ///
  ///
  /// ## PARAMETERS
  ///
  /// [uuid] : The UUID of the presentation to look up.
  ///
  /// - Example (uuid): `3C39C433-5C18-4F51-B357-55BB870227C4`
  ///
  /// ## RESPONSE 204:
  ///
  /// The request was processed successfully. There is no response body.
  ///
  /// content-type: `NONE`
  ///
  static Future<Uint8List> presentationTrigger(String uuid) async {
    String url = '/v1/presentation/$uuid/trigger';

    return await call('get', url);
  }

  /// `presentationTriggerCue` -> `/v1/presentation/{uuid}/trigger/{index}`
  ///
  /// Triggers the specified cue inside the specified presentation.
  ///
  ///
  /// ## PARAMETERS
  ///
  /// [uuid] : The UUID of the presentation to look up.
  ///
  /// - Example (uuid): `3C39C433-5C18-4F51-B357-55BB870227C4`
  ///
  /// [index] : The index of the cue to use. Respects the selected arrangement of cues.
  ///
  /// - Example (index): `0`
  ///
  /// ## RESPONSE 204:
  ///
  /// The request was processed successfully. There is no response body.
  ///
  /// content-type: `NONE`
  ///
  static Future<Uint8List> presentationTriggerCue(String uuid, int index) async {
    String url = '/v1/presentation/$uuid/trigger/$index';

    return await call('get', url);
  }

  /// `presentationActiveTimelineStatus` -> `/v1/presentation/active/timeline`
  ///
  /// Requests the current state of the active presentation timeline.
  ///
  ///
  /// ## RESPONSE 200:
  ///
  /// The request was processed successfully.
  ///
  /// content-type: `application/json`
  ///
  /// schema:
  /// ```json
  /// {
  ///   "type": "object",
  ///   "required": []
  /// }
  /// ```
  static Future<Map<String, dynamic>> presentationActiveTimelineStatus() async {
    String url = '/v1/presentation/active/timeline';

    return await call('get', url);
  }

  /// Streaming version of [presentationActiveTimelineStatus]
  static Future<Stream?> presentationActiveTimelineStatusStream() async {
    String url = '/v1/presentation/active/timeline';

    var uri = Uri.http('$host:$port', url, {'chunked': 'true'});
    return ChunkedJsonClient.request(uri);
  }

  /// `presentationFocusedTimelineStatus` -> `/v1/presentation/focused/timeline`
  ///
  /// Requests the current state of the focused presentation timeline.
  ///
  ///
  /// ## RESPONSE 200:
  ///
  /// The request was processed successfully.
  ///
  /// content-type: `application/json`
  ///
  /// schema:
  /// ```json
  /// {
  ///   "type": "object",
  ///   "required": []
  /// }
  /// ```
  static Future<Map<String, dynamic>> presentationFocusedTimelineStatus() async {
    String url = '/v1/presentation/focused/timeline';

    return await call('get', url);
  }

  /// Streaming version of [presentationFocusedTimelineStatus]
  static Future<Stream?> presentationFocusedTimelineStatusStream() async {
    String url = '/v1/presentation/focused/timeline';

    var uri = Uri.http('$host:$port', url, {'chunked': 'true'});
    return ChunkedJsonClient.request(uri);
  }

  /// `presentationActiveTimelineOperation` -> `/v1/presentation/active/timeline/{operation}`
  ///
  /// Performs the requested timeline operation for the active presentation.
  ///
  ///
  /// ## PARAMETERS
  ///
  /// [operation] : The operation to perform on the timeline
  ///
  /// - Should be one of: `play`, `pause`, `rewind`
  ///
  ///
  /// ## RESPONSE 204:
  ///
  /// The request was processed successfully. There is no response body.
  ///
  /// content-type: `NONE`
  ///
  static Future<Uint8List> presentationActiveTimelineOperation(String operation) async {
    String url = '/v1/presentation/active/timeline/$operation';

    return await call('get', url);
  }

  /// `presentationFocusedTimelineOperation` -> `/v1/presentation/focused/timeline/{operation}`
  ///
  /// Performs the requested timeline operation for the currently active presentation (play, pause, rewind).
  ///
  ///
  /// ## PARAMETERS
  ///
  /// [operation] : The operation to perform on the timeline
  ///
  /// - Should be one of: `play`, `pause`, `rewind`
  ///
  ///
  /// ## RESPONSE 204:
  ///
  /// The request was processed successfully. There is no response body.
  ///
  /// content-type: `NONE`
  ///
  static Future<Uint8List> presentationFocusedTimelineOperation(String operation) async {
    String url = '/v1/presentation/focused/timeline/$operation';

    return await call('get', url);
  }

  /// `presentationTimelineOperation` -> `/v1/presentation/{uuid}/timeline/{operation}`
  ///
  /// Performs the requested timeline operation for the specified presentation (play, pause, rewind).
  ///
  ///
  /// ## PARAMETERS
  ///
  /// [uuid] : The UUID of the presentation to look up.
  ///
  /// - Example (uuid): `3C39C433-5C18-4F51-B357-55BB870227C4`
  ///
  /// [operation] : The operation to perform on the timeline
  ///
  /// - Should be one of: `play`, `pause`, `rewind`
  ///
  ///
  /// ## RESPONSE 204:
  ///
  /// The request was processed successfully. There is no response body.
  ///
  /// content-type: `NONE`
  ///
  static Future<Uint8List> presentationTimelineOperation(String uuid, String operation) async {
    String url = '/v1/presentation/$uuid/timeline/$operation';

    return await call('get', url);
  }

  /// `presentationThumbnailGet` -> `/v1/presentation/{uuid}/thumbnail/{index}`
  ///
  /// Requests a thumbnail image of the specified cue inside the specified presentation at the given quality value.
  ///
  ///
  /// ## PARAMETERS
  ///
  /// [uuid] : The UUID of the presentation to look up.
  ///
  /// - Example (uuid): `3C39C433-5C18-4F51-B357-55BB870227C4`
  ///
  /// [index] : The index of the cue to use. Respects the selected arrangement of cues.
  ///
  /// - Example (index): `0`
  ///
  /// [quality] : The desired quality of the thumbnail. The value is the number of pixels in the _largest_ dimension of the image,
  /// i.e. if the image is landscape (wider than it is tall), it is the _width_ of the image. If the image is portrait
  /// (taller than it is wide), it is the _height_ of the image.
  ///
  /// Example: `400`
  ///
  /// ## RESPONSE 200:
  ///
  /// The request was processed successfully.
  ///
  /// content-type: `image/jpeg`
  ///
  /// schema:
  /// ```json
  /// {
  ///   "type": "string",
  ///   "required": [],
  ///   "format": "binary",
  ///   "example": "image data here"
  /// }
  /// ```
  ///
  /// ## RESPONSE 403:
  ///
  /// The request was not authorized.
  ///
  /// content-type: ``
  ///
  static Future<Uint8List> presentationThumbnailGet(String uuid, int index, {int? quality}) async {
    String url = '/v1/presentation/$uuid/thumbnail/$index';
    Map<String, dynamic> query = {'quality': quality.toString()};

    return await call('get', url, params: query);
  }

  /// `propGetAll` -> `/v1/props`
  ///
  /// Gets a list of all the props.
  ///
  ///
  /// ## RESPONSE 200:
  ///
  /// The request was completed successfully.
  ///
  /// content-type: `application/json`
  ///
  /// schema:
  /// ```json
  /// {
  ///   "type": "array",
  ///   "required": []
  /// }
  /// ```
  static Future<Map<String, dynamic>> propGetAll() async {
    String url = '/v1/props';

    return await call('get', url);
  }

  /// Streaming version of [propGetAll]
  static Future<Stream?> propGetAllStream() async {
    String url = '/v1/props';

    var uri = Uri.http('$host:$port', url, {'chunked': 'true'});
    return ChunkedJsonClient.request(uri);
  }

  /// `propGet` -> `/v1/prop/{id}`
  ///
  /// Requests the details of the specified prop.
  ///
  ///
  /// ## PARAMETERS
  /// [id] (required) :
  /// The ID of the prop, either UUID, name, or index.
  ///
  /// - Example (by_uuid): `3C39C433-5C18-4F51-B357-55BB870227C4`
  /// - Example (by_name): `Prop Name`
  /// - Example (by_index): `3`
  ///
  /// ## RESPONSE 200:
  ///
  /// The request was processed successfully.
  ///
  /// content-type: `application/json`
  ///
  /// schema:
  /// ```json
  /// {
  ///   "type": "object",
  ///   "required": [
  ///     "id"
  ///   ]
  /// }
  /// ```
  static Future<Map<String, dynamic>> propGet(String id) async {
    String url = '/v1/prop/$id';

    return await call('get', url);
  }

  /// `propDelete` -> `/v1/prop/{id}`
  ///
  /// Deletes the specified prop.
  ///
  ///
  /// ## PARAMETERS
  /// [id] (required) :
  /// The ID of the prop, either UUID, name, or index.
  ///
  /// - Example (by_uuid): `3C39C433-5C18-4F51-B357-55BB870227C4`
  /// - Example (by_name): `Prop Name`
  /// - Example (by_index): `3`
  ///
  /// ## RESPONSE 204:
  ///
  /// The request was processed successfully. There is no response body.
  ///
  /// content-type: `NONE`
  ///
  static Future<Uint8List> propDelete(String id) async {
    String url = '/v1/prop/$id';

    return await call('delete', url);
  }

  /// `propTrigger` -> `/v1/prop/{id}/trigger`
  ///
  /// Triggers the specified prop.
  ///
  ///
  /// ## PARAMETERS
  ///
  /// [id] : The ID of the prop, either UUID, name, or index.
  ///
  /// - Example (by_uuid): `3C39C433-5C18-4F51-B357-55BB870227C4`
  /// - Example (by_name): `Prop Name`
  /// - Example (by_index): `3`
  ///
  /// ## RESPONSE 204:
  ///
  /// The request was processed successfully. There is no response body.
  ///
  /// content-type: `NONE`
  ///
  static Future<Uint8List> propTrigger(String id) async {
    String url = '/v1/prop/$id/trigger';

    return await call('get', url);
  }

  /// `propClear` -> `/v1/prop/{id}/clear`
  ///
  /// Clears the specified prop.
  ///
  ///
  /// ## PARAMETERS
  ///
  /// [id] : The ID of the prop, either UUID, name, or index.
  ///
  /// - Example (by_uuid): `3C39C433-5C18-4F51-B357-55BB870227C4`
  /// - Example (by_name): `Prop Name`
  /// - Example (by_index): `3`
  ///
  /// ## RESPONSE 204:
  ///
  /// The request was processed successfully. There is no response body.
  ///
  /// content-type: `NONE`
  ///
  static Future<Uint8List> propClear(String id) async {
    String url = '/v1/prop/$id/clear';

    return await call('get', url);
  }

  /// `propThumbnailGet` -> `/v1/prop/{id}/thumbnail`
  ///
  /// Requests a thumbnail image of the specified prop at the given quality value.
  ///
  ///
  /// ## PARAMETERS
  ///
  /// [id] : The ID of the prop, either UUID, name, or index.
  ///
  /// - Example (by_uuid): `3C39C433-5C18-4F51-B357-55BB870227C4`
  /// - Example (by_name): `Prop Name`
  /// - Example (by_index): `3`
  ///
  /// [quality] : The desired quality of the thumbnail. The value is the number of pixels in the _largest_ dimension of the image,
  /// i.e. if the image is landscape (wider than it is tall), it is the _width_ of the image. If the image is portrait
  /// (taller than it is wide), it is the _height_ of the image.
  ///
  /// Example: `400`
  ///
  /// ## RESPONSE 200:
  ///
  /// The request was processed successfully.
  ///
  /// content-type: `image/jpeg`
  ///
  /// schema:
  /// ```json
  /// {
  ///   "type": "string",
  ///   "required": [],
  ///   "format": "binary",
  ///   "example": "image data here"
  /// }
  /// ```
  static Future<Uint8List> propThumbnailGet(String id, {int? quality}) async {
    String url = '/v1/prop/$id/thumbnail';
    Map<String, dynamic> query = {'quality': quality.toString()};

    return await call('get', url, params: query);
  }

  /// `stageMessageGet` -> `/v1/stage/message`
  ///
  /// Requests the currently active stage message.
  ///
  ///
  /// ## RESPONSE 200:
  ///
  /// The response was processed successfully.
  ///
  /// content-type: `application/json`
  ///
  /// schema:
  /// ```json
  /// {
  ///   "type": "string",
  ///   "required": []
  /// }
  /// ```
  static Future<Map<String, dynamic>> stageMessageGet() async {
    String url = '/v1/stage/message';

    return await call('get', url);
  }

  /// Streaming version of [stageMessageGet]
  static Future<Stream?> stageMessageGetStream() async {
    String url = '/v1/stage/message';

    var uri = Uri.http('$host:$port', url, {'chunked': 'true'});
    return ChunkedJsonClient.request(uri);
  }

  /// `stageMessageShow` -> `/v1/stage/message`
  ///
  /// Shows the specified stage message on the configured stage screen.
  ///
  ///
  /// ## PARAMETERS
  ///
  /// [postBody] (required) : This is the data that must be sent with this request.
  ///
  /// Example:
  /// ```json
  /// "Your message here"
  /// ```
  ///
  /// ## RESPONSE 204:
  ///
  /// The request was processed successfully. There is no response body.
  ///
  /// content-type: `NONE`
  ///
  /// ## RESPONSE 400:
  ///
  /// The request was not valid.
  ///
  /// content-type: ``
  ///
  static Future<Uint8List> stageMessageShow(String postBody) async {
    String url = '/v1/stage/message';

    return await call('put', url);
  }

  /// `stageMessageHide` -> `/v1/stage/message`
  ///
  /// Hides the currently displayed stage message from the configured stage screen.
  ///
  ///
  /// ## RESPONSE 204:
  ///
  /// The request was processed successfully. There is no response body.
  ///
  /// content-type: `NONE`
  ///
  static Future<Uint8List> stageMessageHide() async {
    String url = '/v1/stage/message';

    return await call('delete', url);
  }

  /// `stageLayoutMapGet` -> `/v1/stage/layout_map`
  ///
  /// Requests the currently selected stage layout for each configured stage screen.
  ///
  ///
  /// ## RESPONSE 200:
  ///
  /// The request was processed successfully.
  ///
  /// content-type: `application/json`
  ///
  /// schema:
  /// ```json
  /// {
  ///   "type": "array",
  ///   "required": []
  /// }
  /// ```
  static Future<Map<String, dynamic>> stageLayoutMapGet() async {
    String url = '/v1/stage/layoutMap';

    return await call('get', url);
  }

  /// `stageLayoutMapSet` -> `/v1/stage/layout_map`
  ///
  /// Sets the specified stage message to the corresponding stage screens.
  ///
  ///
  /// ## PARAMETERS
  ///
  /// [postBody] (required) : This is the data that must be sent with this request.
  ///
  /// Example (set_layouts_by_name):
  ///
  /// ```json
  /// [
  ///   {
  ///     "screen": {
  ///       "name": "Side Screen"
  ///     },
  ///     "layout": {
  ///       "name": "Sermon Notes"
  ///     }
  ///   }
  /// ]
  /// ```
  /// Example (set_layouts_by_index):
  ///
  /// ```json
  /// [
  ///   {
  ///     "screen": {
  ///       "index": 3
  ///     },
  ///     "layout": {
  ///       "index": 7
  ///     }
  ///   }
  /// ]
  /// ```
  ///
  /// ## RESPONSE 204:
  ///
  /// The request was processed successfully. There is no response body.
  ///
  /// content-type: `NONE`
  ///
  /// ## RESPONSE 400:
  ///
  /// The request was not valid.
  ///
  /// content-type: ``
  ///
  static Future<Uint8List> stageLayoutMapSet(List postBody) async {
    String url = '/v1/stage/layoutMap';

    return await call('put', url);
  }

  /// `stageScreensGet` -> `/v1/stage/screens`
  ///
  /// Requests a list of the configured stage screens.
  ///
  ///
  /// ## RESPONSE 200:
  ///
  /// The request was processed successfully.
  ///
  /// content-type: `application/json`
  ///
  /// schema:
  /// ```json
  /// {
  ///   "type": "array",
  ///   "required": [],
  ///   "example": [
  ///     {
  ///       "id": {
  ///         "name": "Stage Left",
  ///         "index": 0,
  ///         "uuid": "BB6E8C3A-8182-4818-8D57-38B1D85333A9"
  ///       }
  ///     },
  ///     {
  ///       "id": {
  ///         "name": "Stage Right",
  ///         "index": 1,
  ///         "uuid": "D2BAE32A-CDE2-4166-BA5C-2276D51EEFB8"
  ///       }
  ///     }
  ///   ]
  /// }
  /// ```
  static Future<Map<String, dynamic>> stageScreensGet() async {
    String url = '/v1/stage/screens';

    return await call('get', url);
  }

  /// `stageScreenLayoutGet` -> `/v1/stage/screen/{id}/layout`
  ///
  /// Requests the current stage layout for the specified stage screen.
  ///
  ///
  /// ## PARAMETERS
  ///
  /// [id] : The ID of the screen, either UUID, name, or index.
  ///
  /// - Example (by_uuid): `3C39C433-5C18-4F51-B357-55BB870227C4`
  /// - Example (by_name): `Screen Name`
  /// - Example (by_index): `3`
  ///
  /// ## RESPONSE 200:
  ///
  /// The request was processed successfully.
  ///
  /// content-type: `application/json`
  ///
  /// schema:
  /// ```json
  /// {
  ///   "type": "object",
  ///   "required": [
  ///     "uuid",
  ///     "name",
  ///     "index"
  ///   ]
  /// }
  /// ```
  static Future<Map<String, dynamic>> stageScreenLayoutGet(String id) async {
    String url = '/v1/stage/screen/$id/layout';

    return await call('get', url);
  }

  /// `stageScreenLayoutSet` -> `/v1/stage/screen/{id}/layout/{layout_id}`
  ///
  /// Sets the specified stage layout for the specified stage screen.
  ///
  ///
  /// ## PARAMETERS
  ///
  /// [id] : The ID of the screen, either UUID, name, or index.
  ///
  /// - Example (by_uuid): `3C39C433-5C18-4F51-B357-55BB870227C4`
  /// - Example (by_name): `Screen Name`
  /// - Example (by_index): `3`
  ///
  /// [layoutId] : The ID of the stage layout, either name, index or UUID.
  ///
  /// - Example (by_name): `Layout Name`
  /// - Example (by_index): `3`
  /// - Example (by_uuid): `3C39C433-5C18-4F51-B357-55BB870227C4`
  ///
  /// ## RESPONSE 204:
  ///
  /// The request was processed successfully. There is no response body.
  ///
  /// content-type: `NONE`
  ///
  static Future<Uint8List> stageScreenLayoutSet(String id, String layoutId) async {
    String url = '/v1/stage/screen/$id/layout/$layoutId';

    return await call('get', url);
  }

  /// `stageLayoutsGet` -> `/v1/stage/layouts`
  ///
  /// Requests a list of the configured stage layouts.
  ///
  ///
  /// ## RESPONSE 200:
  ///
  /// The request was processed successfully.
  ///
  /// content-type: `application/json`
  ///
  /// schema:
  /// ```json
  /// {
  ///   "type": "array",
  ///   "required": [],
  ///   "example": [
  ///     {
  ///       "id": {
  ///         "name": "Current/Next Stacked - Music",
  ///         "index": 0,
  ///         "uuid": "4D542943-6CF2-4BEE-A625-7C37B79D8EEF"
  ///       }
  ///     },
  ///     {
  ///       "id": {
  ///         "name": "Main Screen Preview",
  ///         "index": 1,
  ///         "uiuid": "D2BAE32A-CDE2-4166-BA5C-2276D51EEFB8"
  ///       }
  ///     }
  ///   ]
  /// }
  /// ```
  static Future<Map<String, dynamic>> stageLayoutsGet() async {
    String url = '/v1/stage/layouts';

    return await call('get', url);
  }

  /// `stageLayoutDelete` -> `/v1/stage/layout/{layout_id}`
  ///
  /// Deletes the specified stage layout.
  ///
  ///
  /// ## PARAMETERS
  ///
  /// [layoutId] : The ID of the stage layout, either name, index or UUID.
  ///
  /// - Example (by_name): `Layout Name`
  /// - Example (by_index): `3`
  /// - Example (by_uuid): `3C39C433-5C18-4F51-B357-55BB870227C4`
  ///
  /// ## RESPONSE 204:
  ///
  /// The request was processed successfully. There is no response body.
  ///
  /// content-type: `NONE`
  ///
  static Future<Uint8List> stageLayoutDelete(String layoutId) async {
    String url = '/v1/stage/layout/$layoutId';

    return await call('delete', url);
  }

  /// `stageLayoutThumbnailGet` -> `/v1/stage/layout/{layout_id}/thumbnail`
  ///
  /// Requests a thumbnail image of the specified stage layout at the given quality value.
  ///
  ///
  /// ## PARAMETERS
  ///
  /// [layoutId] : The ID of the stage layout, either name, index or UUID.
  ///
  /// - Example (by_name): `Layout Name`
  /// - Example (by_index): `3`
  /// - Example (by_uuid): `3C39C433-5C18-4F51-B357-55BB870227C4`
  ///
  /// [quality] : The desired quality of the thumbnail. The value is the number of pixels in the _largest_ dimension of the image,
  /// i.e. if the image is landscape (wider than it is tall), it is the _width_ of the image. If the image is portrait
  /// (taller than it is wide), it is the _height_ of the image.
  ///
  /// Example: `400`
  ///
  /// ## RESPONSE 200:
  ///
  /// The request was processed successfully.
  ///
  /// content-type: `image/jpeg`
  ///
  /// schema:
  /// ```json
  /// {
  ///   "type": "string",
  ///   "required": [],
  ///   "format": "binary",
  ///   "example": "image data here"
  /// }
  /// ```
  static Future<Uint8List> stageLayoutThumbnailGet(String layoutId, {int? quality}) async {
    String url = '/v1/stage/layout/$layoutId/thumbnail';
    Map<String, dynamic> query = {'quality': quality.toString()};

    return await call('get', url, params: query);
  }

  /// `versionGet` -> `/version`
  ///
  /// Requests the general information about the currently active ProPresenter instance.
  ///
  ///
  /// ## RESPONSE 200:
  ///
  /// The response was processed successfully.
  ///
  /// content-type: `application/json`
  ///
  /// schema:
  /// ```json
  /// {
  ///   "type": "object",
  ///   "required": [
  ///     "name",
  ///     "platform",
  ///     "os_version",
  ///     "host_description",
  ///     "api_version"
  ///   ]
  /// }
  /// ```
  static Future<Map<String, dynamic>> versionGet() async {
    String url = '/version';

    return await call('get', url);
  }

  /// `layerStatusGet` -> `/v1/status/layers`
  ///
  /// Requests the status of all available layers.
  ///
  ///
  /// ## RESPONSE 200:
  ///
  /// The response was processed successfully.
  ///
  /// content-type: `application/json`
  ///
  /// schema:
  /// ```json
  /// {
  ///   "type": "object",
  ///   "required": [
  ///     "video_input",
  ///     "media",
  ///     "slide",
  ///     "announcements",
  ///     "props",
  ///     "messaages",
  ///     "audio"
  ///   ]
  /// }
  /// ```
  static Future<Map<String, dynamic>> layerStatusGet() async {
    String url = '/v1/status/layers';

    return await call('get', url);
  }

  /// Streaming version of [layerStatusGet]
  static Future<Stream?> layerStatusGetStream() async {
    String url = '/v1/status/layers';

    var uri = Uri.http('$host:$port', url, {'chunked': 'true'});
    return ChunkedJsonClient.request(uri);
  }

  /// `stageScreensStatusGet` -> `/v1/status/stage_screens`
  ///
  /// Requests the status of the stage screens.
  ///
  ///
  /// ## RESPONSE 200:
  ///
  /// The response was processed successfully.
  ///
  /// content-type: `application/json`
  ///
  /// schema:
  /// ```json
  /// {
  ///   "type": "boolean",
  ///   "required": []
  /// }
  /// ```
  static Future<Map<String, dynamic>> stageScreensStatusGet() async {
    String url = '/v1/status/stageScreens';

    return await call('get', url);
  }

  /// Streaming version of [stageScreensStatusGet]
  static Future<Stream?> stageScreensStatusGetStream() async {
    String url = '/v1/status/stageScreens';

    var uri = Uri.http('$host:$port', url, {'chunked': 'true'});
    return ChunkedJsonClient.request(uri);
  }

  /// `stageScreensStatusSet` -> `/v1/status/stage_screens`
  ///
  /// Sets the status of the stage screens.
  ///
  ///
  /// ## PARAMETERS
  ///
  /// [postBody] (required) : This is the data that must be sent with this request.
  ///
  /// ## RESPONSE 204:
  ///
  /// The request was processed successfully. There is no response body.
  ///
  /// content-type: `NONE`
  ///
  static Future<Uint8List> stageScreensStatusSet(bool postBody) async {
    String url = '/v1/status/stageScreens';

    return await call('put', url);
  }

  /// `audienceScreensStatusGet` -> `/v1/status/audience_screens`
  ///
  /// Requests the status of the audience screens.
  ///
  ///
  /// ## RESPONSE 200:
  ///
  /// The response was processed successfully.
  ///
  /// content-type: `application/json`
  ///
  /// schema:
  /// ```json
  /// {
  ///   "type": "boolean",
  ///   "required": []
  /// }
  /// ```
  static Future<Map<String, dynamic>> audienceScreensStatusGet() async {
    String url = '/v1/status/audienceScreens';

    return await call('get', url);
  }

  /// Streaming version of [audienceScreensStatusGet]
  static Future<Stream?> audienceScreensStatusGetStream() async {
    String url = '/v1/status/audienceScreens';

    var uri = Uri.http('$host:$port', url, {'chunked': 'true'});
    return ChunkedJsonClient.request(uri);
  }

  /// `audienceScreensStatusSet` -> `/v1/status/audience_screens`
  ///
  /// Sets the status of the audience screens.
  ///
  ///
  /// ## PARAMETERS
  ///
  /// [postBody] (required) : This is the data that must be sent with this request.
  ///
  /// ## RESPONSE 204:
  ///
  /// The request was processed successfully. There is no response body.
  ///
  /// content-type: `NONE`
  ///
  static Future<Uint8List> audienceScreensStatusSet(bool postBody) async {
    String url = '/v1/status/audienceScreens';

    return await call('put', url);
  }

  /// `statusScreensGet` -> `/v1/status/screens`
  ///
  /// Requests the details of all configured screens.
  ///
  ///
  /// ## RESPONSE 200:
  ///
  /// The request was processed successfully.
  ///
  /// content-type: `application/json`
  ///
  /// schema:
  /// ```json
  /// {
  ///   "type": "array",
  ///   "required": []
  /// }
  /// ```
  static Future<Map<String, dynamic>> statusScreensGet() async {
    String url = '/v1/status/screens';

    return await call('get', url);
  }

  /// Streaming version of [statusScreensGet]
  static Future<Stream?> statusScreensGetStream() async {
    String url = '/v1/status/screens';

    var uri = Uri.http('$host:$port', url, {'chunked': 'true'});
    return ChunkedJsonClient.request(uri);
  }

  /// `slideStatusGet` -> `/v1/status/slide`
  ///
  /// Requests the current/next slide text and image UUIDs.
  ///
  ///
  /// ## RESPONSE 200:
  ///
  /// The response was processed successfully.
  ///
  /// content-type: `application/json`
  ///
  /// schema:
  /// ```json
  /// {
  ///   "type": "object",
  ///   "required": []
  /// }
  /// ```
  static Future<Map<String, dynamic>> slideStatusGet() async {
    String url = '/v1/status/slide';

    return await call('get', url);
  }

  /// Streaming version of [slideStatusGet]
  static Future<Stream?> slideStatusGetStream() async {
    String url = '/v1/status/slide';

    var uri = Uri.http('$host:$port', url, {'chunked': 'true'});
    return ChunkedJsonClient.request(uri);
  }

  /// `statusUpdatesGet` -> `/v1/status/updates`
  ///
  /// Aggregates the data from one or more streaming endpoints into a single streaming endpoint.
  ///
  ///
  /// ## PARAMETERS
  ///
  /// [postBody] (required) : This is the data that must be sent with this request.
  ///
  /// Example (one_url):
  ///
  /// ```json
  /// [
  ///   "status/slide"
  /// ]
  /// ```
  /// Example (multi_urls):
  ///
  /// ```json
  /// [
  ///   "status/slide",
  ///   "timer/video_countdown",
  ///   "presentation/current"
  /// ]
  /// ```
  ///
  /// ## RESPONSE 200:
  ///
  /// The request was processed successfully. A stream of updates will be returned to the client as they
  /// become available. Each update is separated by a CRLF pair, so a section of data followed by a
  /// CR-LF-CR-LF sequence is one update. Each update is a JSON object, as below.
  ///
  /// content-type: `application/json`
  ///
  /// schema:
  /// ```json
  /// {
  ///   "type": "object",
  ///   "required": []
  /// }
  /// ```
  ///
  /// ## RESPONSE 400:
  ///
  /// The given request was invalid. This can be caused by a number of things:
  ///   * The given URL was not found.
  ///   * The given URL is not a streaming URL (i.e. it does not return a chunked response).
  ///   * The given URL does not return a JSON data type.
  ///
  /// The response body contains a list of URLs that were not valid.
  ///
  /// content-type: `application/json`
  ///
  /// schema:
  /// ```json
  /// {
  ///   "type": "array",
  ///   "required": []
  /// }
  /// ```
  static Future<Map<String, dynamic>> statusUpdatesGet(List postBody) async {
    String url = '/v1/status/updates';

    return await call('post', url);
  }

  /// `themeGetAll` -> `/v1/themes`
  ///
  /// Requests a list of all configured themes and theme slides.
  ///
  ///
  /// ## RESPONSE 200:
  ///
  /// The request was processed successfully.
  ///
  /// content-type: `application/json`
  ///
  /// schema:
  /// ```json
  /// {
  ///   "type": "array",
  ///   "required": []
  /// }
  /// ```
  static Future<Map<String, dynamic>> themeGetAll() async {
    String url = '/v1/themes';

    return await call('get', url);
  }

  /// `themeGet` -> `/v1/theme/{id}`
  ///
  /// Requests the details of the theme and theme slides.
  ///
  ///
  /// ## PARAMETERS
  /// [id] (required) :
  /// The ID of the theme, either name or index.
  ///
  /// - Example (by_name): `Theme Name`
  /// - Example (by_index): `3`
  ///
  /// ## RESPONSE 200:
  ///
  /// The request was processed successfully.
  ///
  /// content-type: `application/json`
  ///
  /// schema:
  /// ```json
  /// {
  ///   "type": "object",
  ///   "required": [
  ///     "id",
  ///     "slides"
  ///   ]
  /// }
  /// ```
  static Future<Map<String, dynamic>> themeGet(String id) async {
    String url = '/v1/theme/$id';

    return await call('get', url);
  }

  /// `themeSlideGet` -> `/v1/theme/{id}/slides/{theme_slide}`
  ///
  /// Requests the details of the specified theme slide within the specified theme.
  ///
  ///
  /// ## PARAMETERS
  /// [id] (required) :
  /// The ID of the theme, either name or index.
  ///
  /// - Example (by_name): `Theme Name`
  /// - Example (by_index): `3`
  /// [themeSlide] (optional) :
  /// The ID of the theme slide, either name, index or UUID.
  ///
  /// - Example (by_name): `Theme Slide Name`
  /// - Example (by_index): `3`
  /// - Example (by_uuid): `3C39C433-5C18-4F51-B357-55BB870227C4`
  ///
  /// ## RESPONSE 200:
  ///
  /// The request was processed successfully.
  ///
  /// content-type: `application/json`
  ///
  /// schema:
  /// ```json
  /// {
  ///   "type": "object",
  ///   "required": [
  ///     "id"
  ///   ]
  /// }
  /// ```
  static Future<Map<String, dynamic>> themeSlideGet(String id, {String? themeSlide}) async {
    String url = '/v1/theme/$id/slides/$themeSlide';

    return await call('get', url);
  }

  /// `themeSlideSet` -> `/v1/theme/{id}/slides/{theme_slide}`
  ///
  /// Sets the details of the specified theme slide within the specified theme.
  ///
  ///
  /// ## PARAMETERS
  /// [id] (required) :
  /// The ID of the theme, either name or index.
  ///
  /// - Example (by_name): `Theme Name`
  /// - Example (by_index): `3`
  /// [themeSlide] (optional) :
  /// The ID of the theme slide, either name, index or UUID.
  ///
  /// - Example (by_name): `Theme Slide Name`
  /// - Example (by_index): `3`
  /// - Example (by_uuid): `3C39C433-5C18-4F51-B357-55BB870227C4`
  ///
  /// [postBody] (optional) : This is the data that can be sent with this request.
  ///
  /// ## RESPONSE 204:
  ///
  /// The request was processed successfully. There is no response body.
  ///
  /// content-type: `NONE`
  ///
  /// ## RESPONSE 400:
  ///
  /// The request was not valid.
  ///
  /// content-type: ``
  ///
  static Future<Uint8List> themeSlideSet(String id, Map postBody, {String? themeSlide}) async {
    String url = '/v1/theme/$id/slides/$themeSlide';

    return await call('put', url);
  }

  /// `themeSlideThumbnailGet` -> `/v1/theme/{id}/slides/{theme_slide}/thumbnail`
  ///
  /// Requests a thumbnail image of the specified theme slide at the given quality value.
  ///
  ///
  /// ## PARAMETERS
  ///
  /// [id] : The ID of the theme, either name or index.
  ///
  /// - Example (by_name): `Theme Name`
  /// - Example (by_index): `3`
  ///
  /// [themeSlide] : The ID of the theme slide, either name, index or UUID.
  ///
  /// - Example (by_name): `Theme Slide Name`
  /// - Example (by_index): `3`
  /// - Example (by_uuid): `3C39C433-5C18-4F51-B357-55BB870227C4`
  ///
  /// [quality] : The desired quality of the thumbnail. The value is the number of pixels in the _largest_ dimension of the image,
  /// i.e. if the image is landscape (wider than it is tall), it is the _width_ of the image. If the image is portrait
  /// (taller than it is wide), it is the _height_ of the image.
  ///
  /// Example: `400`
  ///
  /// ## RESPONSE 200:
  ///
  /// The request was processed successfully.
  ///
  /// content-type: `image/jpeg`
  ///
  /// schema:
  /// ```json
  /// {
  ///   "type": "string",
  ///   "required": [],
  ///   "format": "binary",
  ///   "example": "image data here"
  /// }
  /// ```
  static Future<Uint8List> themeSlideThumbnailGet(String id, {String? themeSlide, int? quality}) async {
    String url = '/v1/theme/$id/slides/$themeSlide/thumbnail';
    Map<String, dynamic> query = {'quality': quality.toString()};

    return await call('get', url, params: query);
  }

  /// `timerGetAll` -> `/v1/timers`
  ///
  /// Requests the details for all configured timers.
  ///
  ///
  /// ## RESPONSE 200:
  ///
  /// The request was processed successfully.
  ///
  /// content-type: `application/json`
  ///
  /// schema:
  /// ```json
  /// {
  ///   "type": "array",
  ///   "required": []
  /// }
  /// ```
  static Future<Map<String, dynamic>> timerGetAll() async {
    String url = '/v1/timers';

    return await call('get', url);
  }

  /// Streaming version of [timerGetAll]
  static Future<Stream?> timerGetAllStream() async {
    String url = '/v1/timers';

    var uri = Uri.http('$host:$port', url, {'chunked': 'true'});
    return ChunkedJsonClient.request(uri);
  }

  /// `timerCreate` -> `/v1/timers`
  ///
  /// Creates a new timer with the specified details.
  ///
  ///
  /// ## PARAMETERS
  ///
  /// [postBody] (optional) : This is the data that can be sent with this request.
  ///
  /// Example (set_configuration_countdown):
  ///
  /// ```json
  /// {
  ///   "name": "Timer 1",
  ///   "allows_overrun": true,
  ///   "countdown": {
  ///     "duration": 300
  ///   }
  /// }
  /// ```
  /// Example (set_configuration_countdown_to_time):
  ///
  /// ```json
  /// {
  ///   "name": "Timer 1",
  ///   "allows_overrun": true,
  ///   "count_down_to_time": {
  ///     "time_of_day": 3600,
  ///     "period": "pm"
  ///   }
  /// }
  /// ```
  /// Example (set_configuration_elapsed):
  ///
  /// ```json
  /// {
  ///   "name": "Timer 1",
  ///   "allows_overrun": true,
  ///   "elapsed": {
  ///     "start_time": 0,
  ///     "end_time": 120
  ///   }
  /// }
  /// ```
  ///
  /// ## RESPONSE 200:
  ///
  /// The request was processed successfully.
  ///
  /// content-type: `application/json`
  ///
  /// schema:
  /// ```json
  /// {
  ///   "oneOf": [
  ///     {
  ///       "type": "object",
  ///       "required": [
  ///         "id",
  ///         "allows_overrun"
  ///       ]
  ///     },
  ///     {
  ///       "type": "object",
  ///       "required": [
  ///         "id",
  ///         "allows_overrun"
  ///       ]
  ///     },
  ///     {
  ///       "type": "object",
  ///       "required": [
  ///         "id",
  ///         "allows_overrun"
  ///       ]
  ///     }
  ///   ]
  /// }
  /// ```
  ///
  /// ## RESPONSE 400:
  ///
  /// The request was not valid.
  ///
  /// content-type: ``
  ///
  static Future<Map<String, dynamic>> timerCreate(String postBody) async {
    String url = '/v1/timers';

    return await call('post', url);
  }

  /// `timerGetCurrentTimes` -> `/v1/timers/current`
  ///
  /// Requests the current time for all configured timers.
  ///
  ///
  /// ## RESPONSE 200:
  ///
  /// The request was processed successfully.
  ///
  /// content-type: `application/json`
  ///
  /// schema:
  /// ```json
  /// {
  ///   "type": "array",
  ///   "required": []
  /// }
  /// ```
  static Future<Map<String, dynamic>> timerGetCurrentTimes() async {
    String url = '/v1/timers/current';

    return await call('get', url);
  }

  /// Streaming version of [timerGetCurrentTimes]
  static Future<Stream?> timerGetCurrentTimesStream() async {
    String url = '/v1/timers/current';

    var uri = Uri.http('$host:$port', url, {'chunked': 'true'});
    return ChunkedJsonClient.request(uri);
  }

  /// `timerOperationAll` -> `/v1/timers/{operation}`
  ///
  /// Performs the requested operation for all configured timers (start, stop, reset).
  ///
  ///
  /// ## PARAMETERS
  ///
  /// [operation] : The operation to perform on the timer
  ///
  /// - Should be one of: `start`, `stop`, `reset`
  ///
  ///
  /// ## RESPONSE 200:
  ///
  /// The request was processed successfully. There is no response body.
  ///
  /// content-type: ``
  ///
  static Future<Uint8List> timerOperationAll(String operation) async {
    String url = '/v1/timers/$operation';

    return await call('get', url);
  }

  /// `timerGet` -> `/v1/timer/{id}`
  ///
  /// Requests the details of the specified timer.
  ///
  ///
  /// ## PARAMETERS
  /// [id] (required) :
  /// The ID of the timer, either name, index or UUID.
  ///
  /// - Example (by_name): `Timer Name`
  /// - Example (by_index): `3`
  /// - Example (by_uuid): `3C39C433-5C18-4F51-B357-55BB870227C4`
  ///
  /// ## RESPONSE 200:
  ///
  /// The request was processed successfully.
  ///
  /// content-type: `application/json`
  ///
  /// schema:
  /// ```json
  /// {
  ///   "oneOf": [
  ///     {
  ///       "type": "object",
  ///       "required": [
  ///         "id",
  ///         "allows_overrun"
  ///       ]
  ///     },
  ///     {
  ///       "type": "object",
  ///       "required": [
  ///         "id",
  ///         "allows_overrun"
  ///       ]
  ///     },
  ///     {
  ///       "type": "object",
  ///       "required": [
  ///         "id",
  ///         "allows_overrun"
  ///       ]
  ///     }
  ///   ]
  /// }
  /// ```
  static Future<Map<String, dynamic>> timerGet(String id) async {
    String url = '/v1/timer/$id';

    return await call('get', url);
  }

  /// `timerSet` -> `/v1/timer/{id}`
  ///
  /// Sets the details of the specified timer.
  ///
  ///
  /// ## PARAMETERS
  /// [id] (required) :
  /// The ID of the timer, either name, index or UUID.
  ///
  /// - Example (by_name): `Timer Name`
  /// - Example (by_index): `3`
  /// - Example (by_uuid): `3C39C433-5C18-4F51-B357-55BB870227C4`
  ///
  /// [postBody] (required) : This is the data that must be sent with this request.
  ///
  /// Example (set_configuration_countdown):
  ///
  /// ```json
  /// {
  ///   "id": {
  ///     "uuid": "942C3FC3-C4B2-44F7-A55D-4CC913BB8A5D",
  ///     "name": "Timer 1",
  ///     "index": 0
  ///   },
  ///   "allows_overrun": true,
  ///   "countdown": {
  ///     "duration": 300
  ///   }
  /// }
  /// ```
  /// Example (set_configuration_countdown_to_time):
  ///
  /// ```json
  /// {
  ///   "id": {
  ///     "uuid": "942C3FC3-C4B2-44F7-A55D-4CC913BB8A5D",
  ///     "name": "Timer 1",
  ///     "index": 0
  ///   },
  ///   "allows_overrun": true,
  ///   "count_down_to_time": {
  ///     "time_of_day": 3600,
  ///     "period": "pm"
  ///   }
  /// }
  /// ```
  /// Example (set_configuration_elapsed):
  ///
  /// ```json
  /// {
  ///   "id": {
  ///     "uuid": "942C3FC3-C4B2-44F7-A55D-4CC913BB8A5D",
  ///     "name": "Timer 1",
  ///     "index": 0
  ///   },
  ///   "allows_overrun": true,
  ///   "elapsed": {
  ///     "start_time": 0,
  ///     "end_time": 120
  ///   }
  /// }
  /// ```
  ///
  /// ## RESPONSE 200:
  ///
  /// The request was processed successfully.
  ///
  /// content-type: `application/json`
  ///
  /// schema:
  /// ```json
  /// {
  ///   "oneOf": [
  ///     {
  ///       "type": "object",
  ///       "required": [
  ///         "id",
  ///         "allows_overrun"
  ///       ]
  ///     },
  ///     {
  ///       "type": "object",
  ///       "required": [
  ///         "id",
  ///         "allows_overrun"
  ///       ]
  ///     },
  ///     {
  ///       "type": "object",
  ///       "required": [
  ///         "id",
  ///         "allows_overrun"
  ///       ]
  ///     }
  ///   ]
  /// }
  /// ```
  ///
  /// ## RESPONSE 400:
  ///
  /// The request was not valid.
  ///
  /// content-type: ``
  ///
  static Future<Map<String, dynamic>> timerSet(String id, String postBody) async {
    String url = '/v1/timer/$id';

    return await call('put', url);
  }

  /// `timerDelete` -> `/v1/timer/{id}`
  ///
  /// Deletes the specified timer.
  ///
  ///
  /// ## PARAMETERS
  /// [id] (required) :
  /// The ID of the timer, either name, index or UUID.
  ///
  /// - Example (by_name): `Timer Name`
  /// - Example (by_index): `3`
  /// - Example (by_uuid): `3C39C433-5C18-4F51-B357-55BB870227C4`
  ///
  /// ## RESPONSE 204:
  ///
  /// The request was processed successfully. There is no response body.
  ///
  /// content-type: `NONE`
  ///
  static Future<Uint8List> timerDelete(String id) async {
    String url = '/v1/timer/$id';

    return await call('delete', url);
  }

  /// `timerOperation` -> `/v1/timer/{id}/{operation}`
  ///
  /// Performs the requested operation on the specified timer (start, stop, reset).
  ///
  ///
  /// ## PARAMETERS
  ///
  /// [id] : The ID of the timer, either name, index or UUID.
  ///
  /// - Example (by_name): `Timer Name`
  /// - Example (by_index): `3`
  /// - Example (by_uuid): `3C39C433-5C18-4F51-B357-55BB870227C4`
  ///
  /// [operation] : The operation to perform on the timer
  ///
  /// - Should be one of: `start`, `stop`, `reset`
  ///
  ///
  /// ## RESPONSE 204:
  ///
  /// The request was processed successfully. There is no response body.
  ///
  /// content-type: `NONE`
  ///
  static Future<Uint8List> timerOperation(String id, String operation) async {
    String url = '/v1/timer/$id/$operation';

    return await call('get', url);
  }

  /// `timerGetSystemTime` -> `/v1/timer/system_time`
  ///
  /// Requests the current system time.
  ///
  ///
  /// ## RESPONSE 200:
  ///
  /// The request was processed successfully.
  ///
  /// content-type: `application/json`
  ///
  /// schema:
  /// ```json
  /// {
  ///   "type": "integer",
  ///   "required": [],
  ///   "example": 1628029541
  /// }
  /// ```
  static Future<Map<String, dynamic>> timerGetSystemTime() async {
    String url = '/v1/timer/systemTime';

    return await call('get', url);
  }

  /// Streaming version of [timerGetSystemTime]
  static Future<Stream?> timerGetSystemTimeStream() async {
    String url = '/v1/timer/systemTime';

    var uri = Uri.http('$host:$port', url, {'chunked': 'true'});
    return ChunkedJsonClient.request(uri);
  }

  /// `timerGetVideoCountdown` -> `/v1/timer/video_countdown`
  ///
  /// Requests the current value of the video countdown timer.
  ///
  ///
  /// ## RESPONSE 200:
  ///
  /// The request was processed successfully.
  ///
  /// content-type: `application/json`
  ///
  /// schema:
  /// ```json
  /// {
  ///   "type": "string",
  ///   "required": [],
  ///   "example": "00:00:01"
  /// }
  /// ```
  static Future<Map<String, dynamic>> timerGetVideoCountdown() async {
    String url = '/v1/timer/videoCountdown';

    return await call('get', url);
  }

  /// Streaming version of [timerGetVideoCountdown]
  static Future<Stream?> timerGetVideoCountdownStream() async {
    String url = '/v1/timer/videoCountdown';

    var uri = Uri.http('$host:$port', url, {'chunked': 'true'});
    return ChunkedJsonClient.request(uri);
  }

  /// `transportPlay` -> `/v1/transport/{layer}/play`
  ///
  /// Plays the content on the specified layer (presentation, announcement, audio).
  ///
  ///
  /// ## PARAMETERS
  ///
  /// [layer] : The layer to perform the transport operation on
  ///
  /// - Should be one of: `presentation`, `announcement`, `audio`
  ///
  ///
  /// ## RESPONSE 204:
  ///
  /// The request was processed successfully. There is no response body.
  ///
  /// content-type: `NONE`
  ///
  static Future<Uint8List> transportPlay(String layer) async {
    String url = '/v1/transport/$layer/play';

    return await call('get', url);
  }

  /// `transportPause` -> `/v1/transport/{layer}/pause`
  ///
  /// Pauses the content on the specified layer (presentation, announcement, audio).
  ///
  ///
  /// ## PARAMETERS
  ///
  /// [layer] : The layer to perform the transport operation on
  ///
  /// - Should be one of: `presentation`, `announcement`, `audio`
  ///
  ///
  /// ## RESPONSE 204:
  ///
  /// The request was processed successfully. There is no response body.
  ///
  /// content-type: `NONE`
  ///
  static Future<Uint8List> transportPause(String layer) async {
    String url = '/v1/transport/$layer/pause';

    return await call('get', url);
  }

  /// `transportSkipBackward` -> `/v1/transport/{layer}/skip_backward/{time}`
  ///
  /// Moves backward in the content on the specified layer by the specified number of seconds (presentation, announcement, audio).
  ///
  ///
  /// ## PARAMETERS
  ///
  /// [layer] : The layer to perform the transport operation on
  ///
  /// - Should be one of: `presentation`, `announcement`, `audio`
  ///
  /// [time] : The number of seconds to skip
  ///
  /// Example: `15`
  ///
  /// ## RESPONSE 204:
  ///
  /// The request was processed successfully. There is no response body.
  ///
  /// content-type: `NONE`
  ///
  /// ## RESPONSE 400:
  ///
  /// The request was not valid.
  ///
  /// content-type: ``
  ///
  static Future<Uint8List> transportSkipBackward(String layer, int time) async {
    String url = '/v1/transport/$layer/skipBackward/$time';

    return await call('get', url);
  }

  /// `transportSkipForward` -> `/v1/transport/{layer}/skip_forward/{time}`
  ///
  /// Moves forward in the content on the specified layer by the specified number of seconds (presentation, announcement, audio).
  ///
  ///
  /// ## PARAMETERS
  ///
  /// [layer] : The layer to perform the transport operation on
  ///
  /// - Should be one of: `presentation`, `announcement`, `audio`
  ///
  /// [time] : The number of seconds to skip
  ///
  /// Example: `15`
  ///
  /// ## RESPONSE 204:
  ///
  /// The request was processed successfully. There is no response body.
  ///
  /// content-type: `NONE`
  ///
  /// ## RESPONSE 400:
  ///
  /// The request was not valid.
  ///
  /// content-type: ``
  ///
  static Future<Uint8List> transportSkipForward(String layer, int time) async {
    String url = '/v1/transport/$layer/skipForward/$time';

    return await call('get', url);
  }

  /// `transportGoToEnd` -> `/v1/transport/{layer}/go_to_end`
  ///
  /// Moves to the end on a certain layer
  ///
  ///
  /// ## PARAMETERS
  ///
  /// [layer] : The layer to perform the transport operation on
  ///
  /// - Should be one of: `presentation`, `announcement`, `audio`
  ///
  /// [time] : The number of seconds back from the end to move to, 0 if not specified
  ///
  /// Example: `15`
  ///
  /// ## RESPONSE 204:
  ///
  /// The request was processed successfully. There is no response body.
  ///
  /// content-type: `NONE`
  ///
  /// ## RESPONSE 400:
  ///
  /// The request was not valid.
  ///
  /// content-type: ``
  ///
  static Future<Uint8List> transportGoToEnd(String layer, {int? time}) async {
    String url = '/v1/transport/$layer/goToEnd';
    Map<String, dynamic> query = {'time': time.toString()};

    return await call('get', url, params: query);
  }

  /// `transportTimeGet` -> `/v1/transport/{layer}/time`
  ///
  /// Requests the current transport time for the specified layer (presentation, announcement, audio).
  ///
  ///
  /// ## PARAMETERS
  ///
  /// [layer] : The layer to perform the transport operation on
  ///
  /// - Should be one of: `presentation`, `announcement`, `audio`
  ///
  ///
  /// ## RESPONSE 200:
  ///
  /// The request was processed successfully.
  ///
  /// content-type: `application/json`
  ///
  /// schema:
  /// ```json
  /// {
  ///   "type": "number",
  ///   "required": [],
  ///   "example": 15.2
  /// }
  /// ```
  static Future<Map<String, dynamic>> transportTimeGet(String layer) async {
    String url = '/v1/transport/$layer/time';

    return await call('get', url);
  }

  /// Streaming version of [transportTimeGet]
  static Future<Stream?> transportTimeGetStream(String layer) async {
    String url = '/v1/transport/$layer/time';

    var uri = Uri.http('$host:$port', url, {'chunked': 'true'});
    return ChunkedJsonClient.request(uri);
  }

  /// `transportTimeSet` -> `/v1/transport/{layer}/time`
  ///
  /// Moves to the specified time for the specified layer (presentation, announcement, audio).
  ///
  ///
  /// ## PARAMETERS
  ///
  /// [layer] : The layer to perform the transport operation on
  ///
  /// - Should be one of: `presentation`, `announcement`, `audio`
  ///
  /// [postBody] (required) : This is the data that must be sent with this request.
  ///
  /// Example:
  /// ```json
  /// 15.2
  /// ```
  ///
  /// ## RESPONSE 204:
  ///
  /// The request was processed successfully. There is no response body.
  ///
  /// content-type: `NONE`
  ///
  /// ## RESPONSE 400:
  ///
  /// The request was not valid.
  ///
  /// content-type: ``
  ///
  static Future<Uint8List> transportTimeSet(String layer, double postBody) async {
    String url = '/v1/transport/$layer/time';

    return await call('put', url);
  }

  /// `transportAutoAdvanceGet` -> `/v1/transport/{layer}/auto_advance`
  ///
  /// Requests the auto-advance status for the specified layer (presentation, announcement).
  ///
  ///
  /// ## PARAMETERS
  /// [layer] (required) :
  /// The layer to perform the transport operation on
  ///
  /// ## RESPONSE 200:
  ///
  /// The request was processed successfully.
  ///
  /// content-type: `application/json`
  ///
  /// schema:
  /// ```json
  /// {
  ///   "type": "boolean",
  ///   "required": []
  /// }
  /// ```
  static Future<Map<String, dynamic>> transportAutoAdvanceGet(String layer) async {
    String url = '/v1/transport/$layer/autoAdvance';

    return await call('get', url);
  }

  /// `transportAutoAdvanceCancel` -> `/v1/transport/{layer}/auto_advance`
  ///
  /// Cancels the auto-advance for the specified layer (presentation, announcement).
  ///
  ///
  /// ## PARAMETERS
  /// [layer] (required) :
  /// The layer to perform the transport operation on
  ///
  /// ## RESPONSE 204:
  ///
  /// The request was processed successfully. There is no response body.
  ///
  /// content-type: `NONE`
  ///
  static Future<Uint8List> transportAutoAdvanceCancel(String layer) async {
    String url = '/v1/transport/$layer/autoAdvance';

    return await call('delete', url);
  }

  /// `transportCurrentMediaGet` -> `/v1/transport/{layer}/current`
  ///
  /// Requests the details of the currently playing content for the specified layer (presentation, announcement, audio).
  ///
  ///
  /// ## PARAMETERS
  ///
  /// [layer] : The layer to perform the transport operation on
  ///
  /// - Should be one of: `presentation`, `announcement`, `audio`
  ///
  ///
  /// ## RESPONSE 200:
  ///
  /// The request was processed successfully.
  ///
  /// content-type: `application/json`
  ///
  /// schema:
  /// ```json
  /// {
  ///   "type": "object",
  ///   "required": [
  ///     "is_playing",
  ///     "uuid",
  ///     "name",
  ///     "artist",
  ///     "audio_only",
  ///     "length"
  ///   ]
  /// }
  /// ```
  static Future<Map<String, dynamic>> transportCurrentMediaGet(String layer) async {
    String url = '/v1/transport/$layer/current';

    return await call('get', url);
  }

  /// Streaming version of [transportCurrentMediaGet]
  static Future<Stream?> transportCurrentMediaGetStream(String layer) async {
    String url = '/v1/transport/$layer/current';

    var uri = Uri.http('$host:$port', url, {'chunked': 'true'});
    return ChunkedJsonClient.request(uri);
  }

  /// `triggerCue` -> `/v1/trigger/cue/{index}`
  ///
  /// Triggers the specified cue in the currently active playlist item.
  ///
  ///
  /// ## PARAMETERS
  ///
  /// [index] : The index of the cue to use. Respects the selected arrangement of cues.
  ///
  /// - Example (index): `0`
  ///
  /// ## RESPONSE 204:
  ///
  /// The request was processed successfully. There is no response body.
  ///
  /// content-type: `NONE`
  ///
  static Future<Uint8List> triggerCue(int index) async {
    String url = '/v1/trigger/cue/$index';

    return await call('get', url);
  }

  /// `triggerPlaylist` -> `/v1/trigger/playlist/{playlist_id}/{item_id}/{cue_index}`
  ///
  /// Triggers the specified cue in the specified item in the specified playlist.
  ///
  ///
  /// ## PARAMETERS
  ///
  /// [playlistId] : The ID of the playlist, either UUID, name, or index, in order of interpretation and search priority. A path can also be specified to identify playlists within folders. UUID and name matches are searched through the entire playlist tree. Because UUIDs are unique a path is not necessary. A name path is not necessary unless there are multiple playlists with the same name in different folders. A partial path of names can be used as well. Indices only index into the immediate children at each level of the tree so an index path is requred to access playlists within folders if only using indices. A mix of UUIDs, names, and indices can be used for the path if desired.
  ///
  /// - Example (by_uuid): `3C39C433-5C18-4F51-B357-55BB870227C4`
  /// - Example (by_name): `Playlist Name`
  /// - Example (by_name_with_path): `Folder1/Folder2/Playlist Name`
  /// - Example (by_index): `3`
  /// - Example (by_index_path): `2/0/1`
  /// - Example (by_mixed_path): `3C39C433-5C18-4F51-B357-55BB870227C4/Folder Name/0`
  ///
  /// [itemId] : The ID of the item within a playlist, either UUID, name, or index, in order of interpretation and search priority.
  ///
  /// - Example (by_uuid): `3C39C433-5C18-4F51-B357-55BB870227C4`
  /// - Example (by_name): `Presentation Name`
  /// - Example (by_index): `3`
  ///
  /// [cueIndex] : The index of the cue (slide) to use. Respects the selected arrangement of cues. For media playlist items pass 0 here.
  ///
  /// - Example (cue_index): `0`
  ///
  /// ## RESPONSE 204:
  ///
  /// The request was processed successfully. There is no response body.
  ///
  /// content-type: `NONE`
  ///
  static Future<Uint8List> triggerPlaylist(String playlistId, String itemId, int cueIndex) async {
    String url = '/v1/trigger/playlist/$playlistId/$itemId/$cueIndex';

    return await call('get', url);
  }

  /// `triggerMedia` -> `/v1/trigger/media/{playlist_id}/{item_id}`
  ///
  /// Triggers the specified media item in the specified media playlist.
  ///
  ///
  /// ## PARAMETERS
  ///
  /// [playlistId] : The ID of the playlist, either UUID, name, or index, in order of interpretation and search priority. A path can also be specified to identify playlists within folders. UUID and name matches are searched through the entire playlist tree. Because UUIDs are unique a path is not necessary. A name path is not necessary unless there are multiple playlists with the same name in different folders. A partial path of names can be used as well. Indices only index into the immediate children at each level of the tree so an index path is requred to access playlists within folders if only using indices. A mix of UUIDs, names, and indices can be used for the path if desired.
  ///
  /// - Example (by_uuid): `3C39C433-5C18-4F51-B357-55BB870227C4`
  /// - Example (by_name): `Playlist Name`
  /// - Example (by_name_with_path): `Folder1/Folder2/Playlist Name`
  /// - Example (by_index): `3`
  /// - Example (by_index_path): `2/0/1`
  /// - Example (by_mixed_path): `3C39C433-5C18-4F51-B357-55BB870227C4/Folder Name/0`
  ///
  /// [itemId] : The ID of the item within a playlist, either UUID, name, or index, in order of interpretation and search priority.
  ///
  /// - Example (by_uuid): `3C39C433-5C18-4F51-B357-55BB870227C4`
  /// - Example (by_name): `Presentation Name`
  /// - Example (by_index): `3`
  ///
  /// ## RESPONSE 204:
  ///
  /// The request was processed successfully. There is no response body.
  ///
  /// content-type: `NONE`
  ///
  static Future<Uint8List> triggerMedia(String playlistId, String itemId) async {
    String url = '/v1/trigger/media/$playlistId/$itemId';

    return await call('get', url);
  }

  /// `triggerMediaNext` -> `/v1/trigger/media/next`
  ///
  /// Triggers the next item in the currently active media playlist.
  ///
  ///
  /// ## RESPONSE 204:
  ///
  /// The request was processed successfully. There is no response body.
  ///
  /// content-type: `NONE`
  ///
  static Future<Uint8List> triggerMediaNext() async {
    String url = '/v1/trigger/media/next';

    return await call('get', url);
  }

  /// `triggerMediaPrevious` -> `/v1/trigger/media/previous`
  ///
  /// Triggers the previous item in the currently active media playlist.
  ///
  ///
  /// ## RESPONSE 204:
  ///
  /// The request was processed successfully. There is no response body.
  ///
  /// content-type: `NONE`
  ///
  static Future<Uint8List> triggerMediaPrevious() async {
    String url = '/v1/trigger/media/previous';

    return await call('get', url);
  }

  /// `triggerAudio` -> `/v1/trigger/audio/{playlist_id}/{item_id}`
  ///
  /// Triggers the specified audio item in the specified audio playlist.
  ///
  ///
  /// ## PARAMETERS
  ///
  /// [playlistId] : The ID of the playlist, either UUID, name, or index, in order of interpretation and search priority. A path can also be specified to identify playlists within folders. UUID and name matches are searched through the entire playlist tree. Because UUIDs are unique a path is not necessary. A name path is not necessary unless there are multiple playlists with the same name in different folders. A partial path of names can be used as well. Indices only index into the immediate children at each level of the tree so an index path is requred to access playlists within folders if only using indices. A mix of UUIDs, names, and indices can be used for the path if desired.
  ///
  /// - Example (by_uuid): `3C39C433-5C18-4F51-B357-55BB870227C4`
  /// - Example (by_name): `Playlist Name`
  /// - Example (by_name_with_path): `Folder1/Folder2/Playlist Name`
  /// - Example (by_index): `3`
  /// - Example (by_index_path): `2/0/1`
  /// - Example (by_mixed_path): `3C39C433-5C18-4F51-B357-55BB870227C4/Folder Name/0`
  ///
  /// [itemId] : The ID of the item within a playlist, either UUID, name, or index, in order of interpretation and search priority.
  ///
  /// - Example (by_uuid): `3C39C433-5C18-4F51-B357-55BB870227C4`
  /// - Example (by_name): `Presentation Name`
  /// - Example (by_index): `3`
  ///
  /// ## RESPONSE 204:
  ///
  /// The request was processed successfully. There is no response body.
  ///
  /// content-type: `NONE`
  ///
  /// ## RESPONSE 400:
  ///
  /// The request was not valid.
  ///
  /// content-type: ``
  ///
  static Future<Uint8List> triggerAudio(String playlistId, String itemId) async {
    String url = '/v1/trigger/audio/$playlistId/$itemId';

    return await call('get', url);
  }

  /// `triggerAudioNext` -> `/v1/trigger/audio/next`
  ///
  /// Triggers the next item in the currently active audio playlist.
  ///
  ///
  /// ## RESPONSE 204:
  ///
  /// The request was processed successfully. There is no response body.
  ///
  /// content-type: `NONE`
  ///
  static Future<Uint8List> triggerAudioNext() async {
    String url = '/v1/trigger/audio/next';

    return await call('get', url);
  }

  /// `triggerAudioPrevious` -> `/v1/trigger/audio/previous`
  ///
  /// Triggers the previous item in the currently active audio playlist.
  ///
  ///
  /// ## RESPONSE 204:
  ///
  /// The request was processed successfully. There is no response body.
  ///
  /// content-type: `NONE`
  ///
  static Future<Uint8List> triggerAudioPrevious() async {
    String url = '/v1/trigger/audio/previous';

    return await call('get', url);
  }

  /// `triggerVideoInput` -> `/v1/trigger/video_input/{id}`
  ///
  /// Triggers the specified video input in the video input playlist.
  ///
  ///
  /// ## PARAMETERS
  ///
  /// [id] : The ID of the video input, either name, index or UUID.
  ///
  /// - Example (by_name): `Input 1`
  /// - Example (by_index): `3`
  /// - Example (by_uuid): `3C39C433-5C18-4F51-B357-55BB870227C4`
  ///
  /// ## RESPONSE 204:
  ///
  /// The request was processed successfully. There is no response body.
  ///
  /// content-type: `NONE`
  ///
  static Future<Uint8List> triggerVideoInput(String id) async {
    String url = '/v1/trigger/videoInput/$id';

    return await call('get', url);
  }

  /// `triggerLibrary` -> `/v1/trigger/library/{library_id}/{presentation_id}/{index}`
  ///
  /// Triggers the specified slide in the specified presentation in the specified library.
  ///
  ///
  /// ## PARAMETERS
  ///
  /// [libraryId] : The ID of the library, either UUID, name, or index, in order of interpretation and search priority.
  ///
  /// - Example (by_uuid): `3C39C433-5C18-4F51-B357-55BB870227C4`
  /// - Example (by_name): `Library Name`
  /// - Example (by_index): `3`
  ///
  /// [presentationId] : The ID of the presentation, either UUID, name, or index, in order of interpretation and search priority.
  ///
  /// - Example (by_uuid): `3C39C433-5C18-4F51-B357-55BB870227C4`
  /// - Example (by_name): `Presentation Name`
  /// - Example (by_index): `3`
  ///
  /// [index] : The index of the cue to use. Respects the selected arrangement of cues.
  ///
  /// - Example (index): `0`
  ///
  /// ## RESPONSE 204:
  ///
  /// The request was processed successfully. There is no response body.
  ///
  /// content-type: `NONE`
  ///
  /// ## RESPONSE 400:
  ///
  /// The request was not valid.
  ///
  /// content-type: ``
  ///
  static Future<Uint8List> triggerLibrary(String libraryId, String presentationId, int index) async {
    String url = '/v1/trigger/library/$libraryId/$presentationId/$index';

    return await call('get', url);
  }

  /// `triggerNext` -> `/v1/trigger/next`
  ///
  /// Triggers the next cue or item in the currently active playlist or library.
  ///
  ///
  /// ## RESPONSE 204:
  ///
  /// The request was processed successfully. There is no response body.
  ///
  /// content-type: `NONE`
  ///
  static Future<Uint8List> triggerNext() async {
    String url = '/v1/trigger/next';

    return await call('get', url);
  }

  /// `triggerPrevious` -> `/v1/trigger/previous`
  ///
  /// Triggers the previous cue or item in the currently active playlist or library.
  ///
  ///
  /// ## RESPONSE 204:
  ///
  /// The request was processed successfully. There is no response body.
  ///
  /// content-type: `NONE`
  ///
  static Future<Uint8List> triggerPrevious() async {
    String url = '/v1/trigger/previous';

    return await call('get', url);
  }

  /// `videoInputsGet` -> `/v1/video_inputs`
  ///
  /// Requests a list of the configured and triggerable video inputs.
  ///
  ///
  /// ## RESPONSE 200:
  ///
  /// The request was processed successfully.
  ///
  /// content-type: `application/json`
  ///
  /// schema:
  /// ```json
  /// {
  ///   "type": "array",
  ///   "required": []
  /// }
  /// ```
  static Future<Map<String, dynamic>> videoInputsGet() async {
    String url = '/v1/videoInputs';

    return await call('get', url);
  }
}
